#
# spec file for package openstack-glance
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 B1 Systems GmbH, Vohburg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define component glance
%define groupname %{component}
%define username %{component}

%define version_unconverted 18.1.0.dev5

Name:           openstack-%{component}
Version:        18.1.0~dev5
Release:        2.1
Summary:        OpenStack Image Service (Glance)
License:        Apache-2.0
Group:          System/Management
Url:            https://launchpad.net/glance
Source0:        http://tarballs.openstack.org/glance/glance-master.tar.gz
Source2:        %{name}.logrotate
Source3:        %name.conf
Source4:        %name-scrubber.cron
# systemd service files
Source10:       %{name}-api.service
Source12:       %{name}-registry.service
Source50:       README.config
Source99:       rpmlintrc
BuildRequires:  crudini
BuildRequires:  fdupes
BuildRequires:  openstack-suse-macros
BuildRequires:  python-base
BuildRequires:  python-setuptools
# Documentation build requirements:
BuildRequires:  python-Paste
BuildRequires:  python-PasteDeploy
BuildRequires:  python-Routes
BuildRequires:  python-Sphinx
BuildRequires:  python-WSME
BuildRequires:  python-WebOb
BuildRequires:  python-cursive
BuildRequires:  python-debtcollector
BuildRequires:  python-eventlet
BuildRequires:  python-futurist
BuildRequires:  python-glance_store
BuildRequires:  python-keystonemiddleware
BuildRequires:  python-openstackdocstheme
BuildRequires:  python-oslo.concurrency
BuildRequires:  python-oslo.config
BuildRequires:  python-oslo.context
BuildRequires:  python2-oslo.db
BuildRequires:  python-oslo.log
BuildRequires:  python2-oslo.messaging
BuildRequires:  python2-oslo.middleware
BuildRequires:  python-oslo.policy
BuildRequires:  python-oslo.utils
BuildRequires:  python-osprofiler
BuildRequires:  python-pyOpenSSL
BuildRequires:  python-sphinxcontrib-apidoc
BuildRequires:  python-stevedore
BuildRequires:  python-taskflow
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
Requires:       logrotate
Requires:       python >= 2.7
Requires:       python-glance = %{version}
# needed by support for image conversion (qemu-img)
Requires:       qemu-tools
Requires(post): sysconfig
Requires(pre):  pwdutils
%if 0%{?suse_version}
Recommends:     cron
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
The OpenStack Image Service provides discovery, registration and
delivery services for disk and server images. The ability to copy or
snapshot a server image and immediately store it away is a powerful
capability of the OpenStack cloud operating system. Stored images can
be used as a template to get new servers up and running quickly and
more consistently if you are provisioning multiple servers than
installing a server operating system and individually configuring
additional services. It can also be used to store and catalog an
unlimited number of backups.

The Image Service can store disk and server images in a variety of
back-ends, including OpenStack Object Storage. The Image Service API
provides a standard REST interface for querying information about disk
images and lets clients stream the images to new servers.

%package -n python-glance
Summary:        OpenStack Image Service (Glance) - Python module
Group:          Development/Languages/Python
Requires:       python >= 2.6.8
Requires:       python-Paste >= 2.0.2
Requires:       python-PasteDeploy >= 1.5.0
Requires:       python-PrettyTable >= 0.7.1
Requires:       python-Routes >= 2.3.1
Requires:       python-SQLAlchemy >= 1.0.10
Requires:       python-WSME >= 0.8.0
Requires:       python-WebOb >= 1.8.1
Requires:       python-alembic >= 0.8.10
Requires:       python-cryptography >= 2.1
Requires:       python-cursive >= 0.2.1
Requires:       python-debtcollector >= 1.2.0
Requires:       python-defusedxml >= 0.5.0
Requires:       python-eventlet >= 0.18.2
Requires:       python-futurist >= 1.2.0
Requires:       python-glance_store >= 0.22.0
Requires:       python-httplib2 >= 0.9.1
Requires:       python-iso8601 >= 0.1.11
Requires:       python-jsonschema >= 2.6.0
Requires:       python-keystoneauth1 >= 3.4.0
Requires:       python-keystonemiddleware >= 4.17.0
Requires:       python-monotonic >= 0.6
Requires:       python-oslo.concurrency >= 3.26.0
Requires:       python-oslo.config >= 5.2.0
Requires:       python-oslo.context >= 2.19.2
Requires:       python2-oslo.db
Requires:       python-oslo.i18n >= 3.15.3
Requires:       python-oslo.log >= 3.36.0
Requires:       python2-oslo.messaging
Requires:       python2-oslo.middleware
Requires:       python-oslo.policy >= 1.30.0
Requires:       python-oslo.upgradecheck >= 0.1.0
Requires:       python-oslo.utils >= 3.33.0
Requires:       python-osprofiler >= 1.4.0
Requires:       python-pbr >= 2.0.0
Requires:       python-pyOpenSSL >= 17.1.0
Requires:       python-retrying >= 1.2.3
Requires:       python-six >= 1.10.0
Requires:       python-sqlalchemy-migrate >= 0.11.0
Requires:       python-sqlparse >= 0.2.2
Requires:       python-stevedore >= 1.20.0
Requires:       python-taskflow >= 2.16.0

%description -n python-glance
This package contains the core Python module of OpenStack Glance.

%package api
Summary:        OpenStack Image service (Glance) - API
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description api
This package contains the %{name} API server.

%package registry
Summary:        OpenStack Image service (Glance) - Registry
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description registry
This package contains the %{name} Registry server.

%package test
Summary:        OpenStack Image Service (Glance) - Testsuite
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       python-Babel >= 2.3.4
Requires:       python-PyMySQL >= 0.7.6
Requires:       python-fixtures >= 3.0.0
Requires:       python-mock >= 2.0.0
Requires:       python-oslotest >= 3.2.0
Requires:       python-psutil >= 3.2.2
Requires:       python-psycopg2 >= 2.6.2
Requires:       python-pysendfile >= 2.0.0
Requires:       python-requests >= 2.14.2
Requires:       python-sqlalchemy-migrate >= 0.11.0
Requires:       python-swiftclient >= 3.2.0
Requires:       python-testrepository >= 0.0.18
Requires:       python-testresources >= 2.0.0
Requires:       python-testscenarios >= 0.4
Requires:       python-testtools >= 2.2.0
Requires:       python-xattr >= 0.9.2

%description test
The OpenStack Glance testsuite. It is used to verify the functionality
of OpenStack Glance.

%prep
%setup -q -n %{component}-%{version_unconverted}
%openstack_cleanup_prep
# NOTE(tbechtold) without git, openstackdocstheme has warnings which let the doc build fail
sed -i 's/^warning-is-error.*/warning-is-error = 0/g' setup.cfg
crudini --set setup.cfg build_sphinx builder html,man

%build
PBR_VERSION=%{version_unconverted} sphinx-build -b html doc/source doc/build/html
PBR_VERSION=%{version_unconverted} sphinx-build -b man doc/source doc/build/man

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

### directories
install -d -m 755 %{buildroot}%{_localstatedir}/lib/glance
install -d -m 755 %{buildroot}%{_localstatedir}/lib/glance/images
install -d -m 750 %{buildroot}%{_localstatedir}/log/glance
install -d -m 700 %{buildroot}%{_rundir}/%{component}
install -D -m 644 %{SOURCE3} %{buildroot}/%_tmpfilesdir/%name.conf

### configuration files
install -d -m 755 %{buildroot}%{_sysconfdir}/%{component}
mv %{buildroot}/usr/etc/glance/* %{buildroot}%{_sysconfdir}/%{component}
install -d -m 755 %{buildroot}%{_sysconfdir}/%{component}/%{component}.conf.d/
install -d -m 755 %{buildroot}%{_sysconfdir}/%{component}/%{component}-api.conf.d/
install -d -m 755 %{buildroot}%{_sysconfdir}/%{component}/%{component}-registry.conf.d/
install -p -D -m 640 %{SOURCE50} %{buildroot}%{_sysconfdir}/%{component}/README.config

# regenerate the sample config files
for service in api registry scrubber cache manage; do
    PYTHONPATH=. oslo-config-generator --config-file etc/oslo-config-generator/glance-$service.conf
done

cp -pr etc/* %{buildroot}%{_sysconfdir}/glance

for service in api registry scrubber cache manage swift image-import; do
    mv %{buildroot}%{_sysconfdir}/glance/glance-$service.conf{.sample,}
done

rm -rf %{buildroot}%{_sysconfdir}/glance/oslo-config-generator
install -p -D -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
rm -rf %{buildroot}/usr/etc/glance/metadefs # FIXME: is this needed? why is it in the wrong place?

# Install systemd unit services
mkdir -p %{buildroot}%{_sbindir} %{buildroot}%{_unitdir}
install -p -D -m 444 %{SOURCE10} %{buildroot}%{_unitdir}/%{name}-api.service
install -p -D -m 444 %{SOURCE12} %{buildroot}%{_unitdir}/%{name}-registry.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}-api
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}-registry

### documentation
install -d %{buildroot}%{_mandir}/man1
install -m 644 doc/build/man/*.1 %{buildroot}%{_mandir}/man1

### test subpackage
%openstack_test_package_install
%fdupes %{buildroot}%{_localstatedir}/lib/%{name}-test

### misc
%fdupes %{buildroot}%{python_sitelib}/%{component}

### set default configuration
%define glance_conf %{buildroot}%{_sysconfdir}/%{component}/%{component}.conf.d/010-%{component}.conf
crudini --set %{glance_conf} DEFAULT log_dir /var/log/%{component}
crudini --set %{glance_conf} DEFAULT lock_path /var/run/%{component}
crudini --set %{glance_conf} paste_deploy flavor keystone

### authentication cache dir
mkdir -p %{buildroot}%{_localstatedir}/cache/glance/api
mkdir -p %{buildroot}%{_localstatedir}/cache/glance/registry

# Cron jobs
mkdir -p %{buildroot}%{_sysconfdir}/cron.hourly/
install -p -m 755 %{SOURCE4} %{buildroot}%{_sysconfdir}/cron.hourly

%pre
%openstack_pre_user_group_create %{username} %{groupname}

%post
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf

%pre api
%service_add_pre %{name}-api.service

%post api
%service_add_post %{name}-api.service

%preun api
%service_del_preun %{name}-api.service

%postun api
%restart_on_update %{name}-api.service
%service_del_postun %{name}-api.service

%pre registry
%service_add_pre %{name}-registry.service

%post registry
%service_add_post %{name}-registry.service

%preun registry
%service_del_preun %{name}-registry.service

%postun registry
%restart_on_update %{name}-registry.service
%service_del_postun %{name}-registry.service

%files
%defattr(-,root,root)
%doc README.rst
%license LICENSE
%dir %attr(0750, %{username}, %{groupname}) %{_localstatedir}/cache/glance
%dir %{_sysconfdir}/%{component}
%dir %attr(0755, %{username}, %{groupname}) %{_sysconfdir}/%{component}/%{component}.conf.d/
%dir %attr(0755, %{username}, %{groupname}) %{_sysconfdir}/%{component}/%{component}-api.conf.d/
%dir %attr(0755, %{username}, %{groupname}) %{_sysconfdir}/%{component}/%{component}-registry.conf.d/
%{_sysconfdir}/%{component}/README.config
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/glance/glance-api.conf
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/glance/glance-cache.conf
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/glance/glance-registry.conf
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/glance/glance-scrubber.conf
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/glance/glance-swift.conf
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/glance/glance-image-import.conf
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/glance/glance-manage.conf
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/%{component}/%{component}.conf.d/010-%{component}.conf
%config %{_sysconfdir}/glance/glance-api-paste.ini
%config %{_sysconfdir}/glance/glance-registry-paste.ini
%config %{_sysconfdir}/glance/policy.json
%config %{_sysconfdir}/glance/property-protections-policies.conf.sample
%config %{_sysconfdir}/glance/property-protections-roles.conf.sample
%config %{_sysconfdir}/glance/ovf-metadata.json.sample
%config %{_sysconfdir}/glance/schema-image.json
%dir %config %{_sysconfdir}/glance/metadefs
%{_sysconfdir}/glance/metadefs/README
%config %{_sysconfdir}/glance/metadefs/*.json
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%dir %attr(0755, %{username}, %{groupname}) %{_localstatedir}/lib/glance
%dir %attr(0755, %{username}, %{groupname}) %{_localstatedir}/lib/glance/images
%dir %attr(0750, %{username}, %{groupname}) %{_localstatedir}/log/glance
%_tmpfilesdir/%name.conf
%{_bindir}/glance-cache-cleaner
%{_bindir}/glance-cache-manage
%{_bindir}/glance-cache-prefetcher
%{_bindir}/glance-cache-pruner
%{_bindir}/glance-control
%{_bindir}/glance-status
%{_bindir}/glance-manage
%{_bindir}/glance-replicator
%{_bindir}/glance-scrubber
%{_mandir}/man1/glance-api.1%{?ext_man}
%{_mandir}/man1/glance-cache-cleaner.1%{?ext_man}
%{_mandir}/man1/glance-cache-manage.1%{?ext_man}
%{_mandir}/man1/glance-cache-prefetcher.1%{?ext_man}
%{_mandir}/man1/glance-cache-pruner.1%{?ext_man}
%{_mandir}/man1/glance-control.1%{?ext_man}
%{_mandir}/man1/glance-manage.1%{?ext_man}
%{_mandir}/man1/glance-registry.1%{?ext_man}
%{_mandir}/man1/glance-replicator.1%{?ext_man}
%{_mandir}/man1/glance-scrubber.1%{?ext_man}
%dir %attr(0750, %{username}, %{groupname}) %{_localstatedir}/cache/glance
%config(noreplace) %{_sysconfdir}/cron.hourly/%name-scrubber.cron

%files -n python-glance
%defattr(-,root,root,-)
%license LICENSE
%{python_sitelib}/%{component}/
%{python_sitelib}/%{component}-*.egg-info
# Part of test subpackage
%exclude %{python_sitelib}/%{component}/tests/

%files api
%defattr(-,root,root,-)
%{_unitdir}/%{name}-api.service
%{_sbindir}/rc%{name}-api
%{_bindir}/%{component}-api
%{_bindir}/glance-wsgi-api

%files registry
%defattr(-,root,root,-)
%{_unitdir}/%{name}-registry.service
%{_sbindir}/rc%{name}-registry
%{_bindir}/%{component}-registry

%files test
%defattr(-,root,root)
%{python_sitelib}/%{component}/tests/
%{_localstatedir}/lib/%{name}-test/

%changelog
* Sun Mar 24 2019 cloud-devel@suse.de
- Update to version glance-18.1.0.dev5:
  * Imported Translations from Zanata
* Sat Mar 23 2019 cloud-devel@suse.de
- Update to version glance-18.1.0.dev4:
  * Update master for stable/stein
  18.0.0.0rc1
  * Add irrelevant-files for integrated test jobs
  * Add Stein releasenotes
  * Stein example configs refresh
  * Migrate glance-dsvm-grenade-multinode job to Ubuntu Bionic
* Fri Mar 22 2019 cloud-devel@suse.de
- Update to version glance-18.0.0.0b2.dev37:
  * Update irrelevant files
  * Add description to common image properties
* Wed Mar 20 2019 opensuse-packaging@opensuse.org
- Update to version glance-18.0.0.0b2.dev34:
  * Data remains in staging area if 'file' store is not enabled
  * Allow glance tests to run on Windows
  * Windows multiprocess wsgi
  * glance Windows support
  * Update requirement platform checks
  * Imported Translations from Zanata
  * py3: Fix return type on CooperativeReader.read
  * Clarify the Glance/metadefs relationship
  * Document fileystem drv chunk size option
  * Failure in web-dowload kept image in importing state
  * Add job definition locations in comment
  * Add cache-manage utility using v2 API
  * Add new 'all' visibility filter for listing images
  * Add an oslo.policy.enforcer entrypoint
  * add python 3.7 unit test job
  * Fix DeprecationWarnings for RequestContext.tenant/user usage
  * Add test for data migration version
  * Open Stein for data migrations
  18.0.0.0b1
  * Update "Disallowed minor code changes" doc
  * Correct typo in config option choices
  * Use renamed template 'integrated-gate-py3'
  * Make QuotaImageTagsProxy deep-copyable
  * Update show\_multiple\_locations deprecation note
  * Guard \_\_getattr\_\_ on QuotaImageTagsProxy
  * Fix for FK constraint violation
  * Image conversion fails
  * Implement scaffolding for upgrade checks
  * Drop dependency on monotonic
  * Remove i18n.enable\_lazy() call from glance.cmd
  * Imported Translations from Zanata
  * Update mailinglist from dev to discuss
  * Add definition for hw\_time\_hpet image property
  * [doc] Fix options group for default\_backend
  * Add missing ws seperator between words
  * Embed validation data in locations
  * Imported Translations from Zanata
  * Make the link to release notes anonymous
  * py3: fix recursion issue under py37
  * Remove moxstubout usage
  * Increment versioning with pbr instruction
  * Fixed intermittent timeout/failing functional tests
  * Use tempest-pg-full
  * Refactor periodic "tips" jobs
  * Do not use Accept.best\_match
  * Replace openSUSE experimental check with newer version
  * Do not use oslo.messaging 9.0.0
  * fix "it's" typos
  * Imported Translations from Zanata
  * Provision to add new config options in sample config file
  * Cleanup .zuul.yaml
  * add python 3.6 unit test job
  * switch documentation job to new PTI
  * Remove rootwrap.conf file from setup.cfg
  * Imported Translations from Zanata
  * import zuul job settings from project-config
  * Revert "Add a default rootwrap.conf file."
  * Add missing tests for 2.6 statuses
  * Use WebOb 1.8.1
  * Update Ubuntu install guide
  * Handle StopIteration for Py3.7 PEP 0479
  * Rename async package to async\_
* Mon Nov 19 2018 sjamgade@suse.com
- change service depedancy from mysql.service to mariadb.service
* Tue Sep  4 2018 dmueller@suse.com
- update PyMySQL dependency
* Tue Aug 28 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0rc2.dev23:
  * Remove qpid-python from test-requirements
  * Remove stub\_out\_registry\_server method
* Sun Aug 26 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0rc2.dev19:
  * Update status to active when locations replaced
* Mon Aug 20 2018 nicolas.bock@suse.com
- Fix linter warnings about licenses
* Sun Aug 19 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0rc2.dev17:
  * Imported Translations from Zanata
* Fri Aug 17 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0rc2.dev16:
  * api-ref: "hidden" images update
  * Remove broken bandit from testing
  * Add multihash checks to functional tests
  * Support RFC1738 quoted chars in passwords
  * Update "Release Notes" in contributor docs
* Wed Aug 15 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0rc2.dev8:
  * Update README
* Mon Aug 13 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0rc2.dev6:
  * Imported Translations from Zanata
* Sat Aug 11 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0rc2.dev5:
  * Imported Translations from Zanata
  * Update reno for stable/rocky
  * Don't run ssl-handshake job on doc changes
  17.0.0.0rc1
  * Introduce ''mock\_object'' method to base test class
* Fri Aug 10 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b4.dev24:
  * Add prelude to Rocky releasenotes
  * Add release note for multi-store feature
  * Imported Translations from Zanata
  * api-ref: update version history
* Thu Aug  9 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b4.dev19:
  * Add API version 2.8
  * Sync Rocky example configs
  * Document hw\_cpu\_policy and hw\_cpu\_thread\_policy image properties
* Wed Aug  8 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b4.dev13:
  * api-ref: make the discovery section more general
  * Replace mox with mock
  * Unit/Functional tests for multi store support
* Tue Aug  7 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b4.dev7:
  * Correct typo in help text
  * Doc:Multiple stores support
* Fri Aug  3 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b4.dev4:
  * Bump Imges API version to 2.7
  * Add multi-store support
* Thu Aug  2 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b4.dev1:
  * Multihash implementation for Glance
  17.0.0.0b3
* Sat Jul 28 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b3.dev24:
  * Remove Images API v1 entry points
* Fri Jul 27 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b3.dev22:
  * Hide old images
* Wed Jul 18 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b3.dev21:
  * Update glance documentation for trait support
* Tue Jul 17 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b3.dev19:
  * Use glance.context.RequestContext in tests
* Wed Jul 11 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b3.dev18:
  * fix tox python3 overrides
* Tue Jul 10 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b3.dev17:
  * replace cmp with total\_ordering decorator
* Sat Jul  7 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b3.dev16:
  * Documentation for OSSN-0075 mitigation
  * Change default age of purge\_images\_table to 180
  * Mitigate OSSN-0075
* Fri Jul  6 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b3.dev11:
  * Prevent taskflow creation in impossible import
* Wed Jul  4 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b3.dev9:
  * useful-image-properties.rst: Update default RNG source
* Thu Jun 21 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b3.dev8:
  * Replace Chinese punctuation with English punctuation
* Wed Jun 20 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b3.dev7:
  * Update Release CPL doc about periodic jobs
  * Use group\_regex to serialize scrubber tests
  * Convert to string before using assertIn
  * Refactor wait\_for\_scrubber\_shutdown function
* Wed Jun 13 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b3.dev3:
  * Add image conversion plugin
  17.0.0.0b2
* Fri Jun  8 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b2.dev39:
  * Regenerate sample config files
  * Remove deprecated 'enable\_image\_import' option
  * convert windows line endings to unix format
  * Refactor exception handling in cmd.api
* Thu Jun  7 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b2.dev31:
  * Add glance-eventlet-ssl-handshake-broken-py35 job
* Wed Jun  6 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b2.dev30:
  * Fix wrong scheduler\_hints name in CIM::ProcessorAllocationSettingData
  * Modify the empty list ensure method
* Tue Jun  5 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b2.dev26:
  * Add periodic tips jobs
  * Fix unreachable 'ImageSizeLimitExceeded' exception in image-upload
  * Update pypi url to new url
* Sat Jun  2 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b2.dev20:
  * Add py35 statement
* Thu May 31 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b2.dev19:
  * update "auth\_url" in document
* Tue May 15 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b2.dev17:
  * Update some url links of rally/README.rst
  * correct grammar, duplicate a found
* Fri May 11 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b2.dev15:
  * Prevent early exit from functional tests
  * Prepare for WebOb 1.8.1
* Wed May  9 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b2.dev12:
  * Run scrubber functional tests in serial mode
* Sun May  6 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b2.dev11:
  * [api-ref] "Show images" should be changed to "List images"
* Fri May  4 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b2.dev9:
  * Add time-bounded wait-for-status to func tests
* Thu May  3 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b2.dev8:
  * Add 'useful image properties' document
  * Follow the OpenStack Sphinx theme configuration
* Mon Apr 30 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b2.dev5:
  * Add redirect capability to glance docs
* Thu Apr 26 2018 cloud-devel@suse.de
- Update to version glance-17.0.0.0b2.dev3:
  * Remove all usage of keystoneclient
* Tue Apr 24 2018 tbechtold@suse.com
- Update to version glance-17.0.0.0b2.dev2:
  * Pending-delete rollback ability
  17.0.0.0b1
  * Cleaning image data when image signature verification fails
  * Imported Translations from Zanata
  * Add info about building the v1 api-ref
  * Follow the new PTI for document build
  * Fix incompatible requirement in requirement.txt
  * Migrate legacy job to project repository
  * Add fixture to limit unit test log output
  * Refactor scrubber functional test
  * Update auth\_uri option to www\_authenticate\_uri
  * Change the outdated links to the latest links in README
  * Remove v1 tests
* Wed Apr 11 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev107:
  * Update image schema with Image API 2.6 statuses
* Tue Apr 10 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev105:
  * add lower-constraints job
* Mon Apr  9 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev103:
  * Use 'Default' as sample install domain name
* Sat Apr  7 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev102:
  * Functional tests for new Image Import API
* Fri Apr  6 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev100:
  * Update auth\_url in install docs
  * Fix web-download fails with default node\_staging\_uri
* Wed Apr  4 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev96:
  * Make functional tests run by default
* Tue Apr  3 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev94:
  * Imported Translations from Zanata
  * Python 3.5: Image Import fails with Unicode Error
* Sat Mar 31 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev90:
  * Make eventlet monkey patching conform to best practices
  * Update Glance landing pages
* Tue Mar 27 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev87:
  * Updated from global requirements
* Wed Mar 21 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev86:
  * Update Release CPL doc
  * Use oslo\_db.sqlalchemy.test\_fixtures
* Tue Mar 20 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev82:
  * Deprecate owner\_is\_tenant
  * Updated from global requirements
  * Use config opt value to determine import methods
* Fri Mar 16 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev77:
  * Clean the web-download tests
* Wed Mar 14 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev75:
  * Fix format in doc/source/cli/\*
* Tue Mar 13 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev73:
  * Updated from global requirements
* Mon Mar 12 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev72:
  * Imported Translations from Zanata
* Sat Mar 10 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev71:
  * Delete the superfluous symbol of the command line
  * Add barbican-tempest experimental job
  * Unit tests for Web-Download import method
  * api-ref: fix list-resource-type-assocs example
* Fri Mar  9 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev63:
  * Open Rocky for data migrations
  * api-ref: correct typo
  * Fix format cache.rst
* Wed Mar  7 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev58:
  * Remove v1 from API ref
  * Imported Translations from Zanata
  * Update installation guide: no uwsgi for glance
  * Remove use of mox/mox3
* Fri Mar  2 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev51:
  * Imported Translations from Zanata
  * [doc] Modify the description for the command
* Thu Feb 22 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev49:
  * Hide Pike note on Queens Release Notes page
  * Triggers shouldn't be execute in offline migration
  * Revise help text for uri filtering options
  * Revise database rolling upgrade documentation
  * Correct length limit for custom property value
  * Fix config group not found error
  * api-ref: update interoperable image import info
  * Updated from global requirements
  2011.2
  0.1.7
* Wed Feb 21 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev35:
  * Migration support for postgresql
* Tue Feb 20 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev34:
  * Revise interoperable image import documentation
  * Add validation to check if E-M-C is already in sync
* Sat Feb 17 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev30:
  * Update Queens info about Glance and uWSGI
  * Imported Translations from Zanata
* Fri Feb 16 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev28:
  * Update admin docs for web-download import method
  * URI filtering for web-download
  * Imported Translations from Zanata
  * Make the Image status transition early
* Thu Feb 15 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev21:
  * Cleanup basic import tasks
  * Use bool instead of int for boolean filter value
* Wed Feb 14 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0rc2.dev18:
  * image-guide: Update cirros image
  * Limit default workers to 8
* Tue Feb 13 2018 tbechtold@suse.com
- Update to version glance-16.0.0.0rc2.dev15:
  * Imported Translations from Zanata
  * Imported Translations from Zanata
  * Use configured value for import-methods header
  * Fix bad usage of extend in list\_image\_import\_opts
  * Revert "Fix wrong usage of extend in list\_image\_import\_opts"
  * Offline migration support for postgresql
  * Fix wrong usage of extend in list\_image\_import\_opts
  * Imported Translations from Zanata
  * Update reno for stable/queens
  16.0.0.0rc1
  * Update Queens metadefs release note
  * Update api-ref for v.2.6
  * Add release note for API v2.6
  * Align Vers Neg Middleware to current API
  * Implementation of db check command
  * Decouple Image Import Plugin Opts
  * Revise import property injection plugin releasenote
  * Correct 1-character typo
  * Release note for Queens metadefs changes
  * Regenerate sample configuration files
  * Exiting with user friendly message and SystemExit()
  * Modify glance manage db sync to use EMC
  * Add img\_linked\_clone to compute vmware metadefs
  * Handle TZ change in iso8601 >=0.1.12
  * Replace xml defusedxml
  * Replace base functional tearDown with addCleanup
  * Add functional test gates
  * Skip one functional test
  * Fix py27 eventlet issue <0.22.0
  * Fix pip install failure
  * Execute py35 functional tests under py35 environment
  * Enable Image Import per default and make current
  * Adds 'web-download' import method
  * Updated from global requirements
  * Skip one functional test
  * Use addOnException to capture server logs on failure
  * Update Signature Documentation
  * Implementation of Inject metadata properties
  * Resolve unit test failures with going to oslo.serialization 2.3.0
  16.0.0.0b3
  * Update the valid disk bus list for qemu and kvm hypervisors
  * Delete data if image is deleted after staging call
* Wed Jan 24 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0b3.dev31:
  * Separate out functional tests
  * Add doc8 to pep8 check for glance project
* Fri Jan 19 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0b3.dev28:
  * Updated from global requirements
* Thu Jan 18 2018 cloud-devel@suse.de
- Update to version glance-16.0.0.0b3.dev27:
  * Updated from global requirements
  * Add documentation for image import plugins
* Mon Jan 15 2018 tbechtold@suse.com
- Update to version glance-16.0.0.0b3.dev24:
  * Update scrubber documentation
  * Scrubber refactor
  * Add hooks for Image Import plugins
  * Updated from global requirements
  * Fix 500 if custom property name is greater than 255
  * Fix member create to handle unicode characters
  * [import-tests] adds tests for image-import/staging
  * Updated from global requirements
  * [import-tests] Enhance image import tests
  * Add fixture to only emit DeprecationWarning once
  * Move 'upload\_image' policy check to the controller
  * Fix 500 from duplicate stage call
  * Prevent image become active without disk and container formats
  16.0.0.0b2
  * Fix 500 on ValueError during image-import
  * Update the documentation links
  * Add the list of hw\_version supported by vmware driver
  * Updated from global requirements
  * Utilize LimitingReader for staging data
  * Fix 500 from image-import on 'active' image
  * Fix 500 from stage call on non-existing image
  * Fix unstage after staging store denies write
  * Updated from global requirements
  * Fix 500 from image-import on queued images
  * Use new oslo.context arg names
  * Use new oslo.db base test case
  * Fix the wrong URL
  * Correct related section for enable\_image\_import
  * Fix SQLAlchemy reference link
  * Remove setting of version/release from releasenotes
  * Updated from global requirements
  * Fix format of configuration/configuring.rst
  * Removing unreachable line from stage() method
  * Wrong description in ImageMembersController.update
  * Updated from global requirements
  * Updated from global requirements
  * Correct sphinx syntax of glance doc
  * Update http deploy docs to be a bit more explicit
  * Clarify log message
  * Make ImageTarget behave like a dictionary
  * Remove use of deprecated optparse module
  * Replace DbMigrationError with DBMigrationError
  * Add default configuration files to data\_files
  * Align default policy in code with the one in conf
  * Optimize the way to serach file 'glance-api-paste.ini'
  * Properly validate metadef objects
  * Changes behaviour when an image fails uploading
* Sat Nov  4 2017 cloud-devel@suse.de
- Update to version glance-16.0.0.0b2.dev7:
  * Updated from global requirements
* Tue Oct 31 2017 cloud-devel@suse.de
- Update to version glance-16.0.0.0b2.dev6:
  * tests: replace .testr.conf with .stestr.conf
* Sat Oct 28 2017 cloud-devel@suse.de
- Update to version glance-16.0.0.0b2.dev5:
  * Updated from global requirements
* Wed Oct 25 2017 cloud-devel@suse.de
- Update to version glance-16.0.0.0b2.dev4:
  * Document new URL format
  * Update api-ref about 403 for image location changes
  16.0.0.0b1
  * Revert "Remove team:diverse-affiliation from tags"
* Fri Oct 20 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev73:
  * Document Glance Registry deprecation
  * Replace body\_file with class to call uwsgi.chunked\_read()
* Mon Oct 16 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev69:
  * Deprecate Registry and it's config opts
  * Update Rally Job related files
  * Alembic should use oslo\_db facades
* Fri Oct 13 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev64:
  * Update spec-lite info in contributors' docs
  * Add a local bindep.txt override
* Sat Oct  7 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev62:
  * Fix 500 if user passes name with more than 80 characters
  * Clean up api-ref index page
* Sat Sep 30 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev59:
  * TrivialFix: Fix wrong test case
* Wed Sep 27 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev57:
  * Updated from global requirements
  * Fix a typo in swift\_store\_utils.py: replace Vaid with Valid
  * Update image statuses doc for latest change
* Fri Sep 22 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev53:
  * Switch base to latest in link address
  * Fix missing some content of glance database creation
  * Updated from global requirements
  * Clean up database section of admin docs
  * Avoid restarting a child when terminating
  * Open Queens for data migrations
* Thu Sep 14 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev42:
  * Add image import docs to admin guide
  * Updated from global requirements
* Sat Sep  2 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev38:
  * Updated from global requirements
* Fri Sep  1 2017 ashwin.agate@suse.com
- Update package dependencies
  * moved following dependencies to test package Requires
  * python-Babel
  * python-psutil
  * python-xattr
- * updated version for python-glance_store
  * remove duplicate python-cursive from Requires
* Thu Aug 31 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev37:
  * Change variable used by log message
  * api-ref: add 'protected' query filter
  * Update invalid links of User doc
  * Add the missing i18n import
* Tue Aug 29 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev31:
  * Update URL home-page in documents according to document migration
* Sat Aug 26 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev30:
  * Separate module reference from contributor/index page
* Fri Aug 25 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev28:
  * Updated from global requirements
* Thu Aug 24 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev27:
  * Fix api\_image\_import tasks stuck in 'pending'
* Tue Aug 22 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev25:
  * Correct group name in config
  * api-ref: add interoperable image import docs
  * Add release note for Glance Pike RC-2
  * Fix Image API 'versions' response
  * Updated from global requirements
  * Return 404 for import-info call
  * Fix 500 error from image-import call
* Sat Aug 19 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev11:
  * Add 'tasks\_api\_access' policy
  * Add 'api\_image\_import' type to task(s) schemas
  * Fix 500 error from image-stage call
  * api-ref: update container\_format, disk\_format
* Thu Aug 17 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev4:
  * Update invalid path and link for Image Properties
* Sat Aug 12 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0rc2.dev3:
  * Imported Translations from Zanata
  * Update reno for stable/pike
  15.0.0.0rc1
* Fri Aug 11 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b4.dev19:
  * Refresh config files for Pike RC-1
  * Add release note for RC-1 including metadefs changes
  * Fix trust auth mechanism
  * Prevent v1\_api from making requests to v2\_registry
* Thu Aug 10 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b4.dev14:
  * Updated from global requirements
* Tue Aug  8 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b4.dev13:
  * Bump Images API to v2.6
* Sat Aug  5 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b4.dev11:
  * Remove datastore\_name and datacenter\_path
* Thu Aug  3 2017 cloud-devel@suse.de
- Rebased patches:
  + 0001-doc-Explicitly-set-builders-option.patch dropped (merged upstream)
  + 0001-doc-Explicitly-set-builders-option.patch dropped (merged upstream)
* Thu Aug  3 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b4.dev10:
  * Update the documention for doc migration
  * doc: Explicitly set 'builders' option
* Wed Aug  2 2017 tbechtold@suse.com
- Update to version glance-15.0.0.0b4.dev7:
  * Create image fails if 'enable\_image\_import' is set
  * Updated from global requirements
  * Add a default rootwrap.conf file
  15.0.0.0b3
  * Remove team:diverse-affiliation from tags
* Fri Jul 28 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b3.dev85:
  * Updated from global requirements
  * Add release note for wsgi containerization
* Thu Jul 27 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b3.dev82:
  * Fix typo in discovery API router
* Wed Jul 26 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b3.dev81:
  * Fix glance image-download error
  * Fix filter doesn't support non-ascii characters
* Mon Jul 24 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b3.dev78:
  * Updated from global requirements
* Thu Jul 20 2017 snica@suse.com
- Remove deprecated keystone_authtoken/signing_dir
  The keystone_authtoken/signing_dir configuration
  option is deprecated and can be removed (PKI token
  support has been deprecated in the Ocata release and
  will be removed in the Pike release).
* Thu Jul 20 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b3.dev77:
  * Updated from global requirements
  * Add Discovery stub for Image Import
* Wed Jul 19 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b3.dev73:
  * Satisfy API Reference documentation deleting tags
* Wed Jul 12 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b3.dev71:
  * Handle file delete races in image cache
* Tue Jul 11 2017 tbechtold@suse.com
- Update to version glance-15.0.0.0b3.dev69:
  * Add 'protected' filter to image-list call
- Add 0001-doc-Explicitly-set-builders-option.patch
* Thu Jul  6 2017 tbechtold@suse.com
- Update to version glance-15.0.0.0b3.dev67:
  * Remove unused None from dict.get()
* Mon Jul  3 2017 tbechtold@suse.com
- Update to version glance-15.0.0.0b3.dev65:
  * Updated from global requirements
  * Remove unused parameter from 'stop\_server' method
  * use openstackdocstheme html context
  * update doc URLs in the readme
  * only show first heading from the glossary on home page
  * move links to older install guides to the current install guide
  * switch to openstackdocstheme
  * import the cli examples from the admin guide in openstack-manuals
  * import troubleshooting section of admin guide from openstack-manuals
  * import the installation guide from openstack-manuals
  * import the glossary from openstack-manuals
  * turn on warning-is-error for sphinx build
  * Clean up the redundant code
  * Imported Translations from Zanata
  * Add metadefs release note for Pike
  * Updated from global requirements
  * do not declare code blocks as json when they do not parse
  * use :ref: instead of :doc: for xref
  * add index page to cli dir
  * fix image path
  * fix include directives
  * fix repeated hyperlink target names
  * fix the autodoc instructions
  * rearrange existing documentation to follow the new layout standard
  * Make i18n log translation functions as no-op
  * Remove unused variable
  * Tests: Remove the redundant methods
  * ignore generated sample config files
  * Fix broken link to the "Image service property keys" doc
  * Add docs and sample configs for running glance with apache
  * Add pbr wsgi script entrypoint to glance
  * Add external lock to image cache sqlite driver db init
  * Updated from global requirements
  * Add hide hypervisor id on guest host
  * Change keystoneclient to keystoneauth1
  * Fix some reST field lists in docstrings
  * Fix some reST field lists in docstrings
  * Update vmware metadef with ESX 6.5 supported OSes
* Fri Jun 16 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b3.dev9:
  * Fix doc generation for Python3
* Wed Jun 14 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b3.dev8:
  * Remove use of config enforce\_type=True
  * Remove duplicate key from dictionary
  * Trivial fix
  * Log at error when we intend to reraise the exception
* Tue Jun 13 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b3.dev3:
  * Remove usage of parameter enforce\_type
* Sat Jun 10 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b3.dev2:
  15.0.0.0b2
  * Add import endpoint to initiate image import
  * Add images/<id>/staging endpoint
* Thu Jun  8 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev42:
  * Updated from global requirements
  * Support new OSProfiler API
* Tue Jun  6 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev39:
  * Addresses the comments from review 391441
* Sat Jun  3 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev37:
  * Updated from global requirements
  * Updated from global requirements
* Fri Jun  2 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev35:
  * Stop enforcing translations on logs
* Thu Jun  1 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev33:
  * Fixed PY35 Jenkins Gate warnings
  * Clean up py35 env in tox.ini
* Tue May 30 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev29:
  * Fix vmware option for glance\_store
* Sun May 28 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev27:
  * Updated from global requirements
* Sat May 27 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev26:
  * Add OpenStack-image-import-methods header
  * WIP:Add api\_image\_import flow
* Fri May 26 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev22:
  * Updated from global requirements
* Mon May 22 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev21:
  * Updated from global requirements
* Fri May 12 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev20:
  * Add node\_staging\_uri and enable\_image\_import opts
* Wed May 10 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev18:
  * Fix periodic py27 oslo-with-master test
* Fri May  5 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev17:
  * Updated from global requirements
  * Fix wrong overridden value of config option client\_socket\_timeout
* Tue May  2 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev14:
  * Remove test\_unsupported\_default\_store
* Sat Apr 29 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev13:
  * Clean up acceptable values for 'store\_type\_preference'
  * Fix tests when CONF.set\_override with enforce\_type=True
* Thu Apr 27 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev9:
  * Fix the mismatch of title and content
  * Fix and enable test\_cache\_middleware test on py35
  * Invoke monkey\_patching early enough for eventlet 0.20.1
  * Mock CURRENT\_RELEASE for migration unit test
  * Update deprecated show\_multiple\_locations helptext
  * Eliminate reference to metadefs 'namespace\_id'
  * Add image update tests for is\_public
  * Fix NameError in metadef\_namespaces.py
  * remove useless EVENTLET\_NO\_GREENDNS
  * Add ploop to supported disk\_formats
  * Expand hypervisor\_type meta data with Virtuozzo hypervisor
  * Change cfg.set\_defaults into cors.set\_defaults
  * Python3: fix glance.tests.functional.v2.test\_images
  * Python 3: fix glance.tests.functional.v1.test\_misc
  * Python3: fix glance.tests.functional.test\_scrubber
  * Python3: fix logs/glance.tests.functional.test\_healthcheck\_middleware
  * Python3: Fix glance.tests.functional.test\_glance\_replicator
  * Python3: Fix glance.tests.functional.test\_bin\_glance\_cache\_manage
  * Python 3: fix glance.tests.functional.db.test\_sqlalchemy
  * Python3: fix test\_client\_redirects.py
  * Added overwrite warning for db\_export\_metadefs
  * Allow specifying OS\_TEST\_PATH (to reduce tests ran)
  * ping\_server: Always close the socket
  * Image signature documentation modify barbican auth\_endpoint
  * Add libvirt image metadef for hw\_pointer\_model
  * Fix incorrect call for \_gen\_uuid
  * Update description of image\_destroy method
  * Remove self.\_\_dict\_\_ for formatting strings
  * Improving help text for send\_identity\_headers opt
  * Deprecate \`show\_multiple\_locations\` option
  * Improving help text for image conversion\_format
  * Improving help text for store\_type\_preference opt
  * Removing deprecated variable aliases from oslo\_messaging
  * Add registry\_client\_opts to glance-cache.conf.sample
  * Don't use config option sqlite\_db
  * Improving help text for location\_strategy opt
  * Improving help text for swift\_store\_utils opts
  * cache\_manage: fix a print bug in exit main
  * Add 'ova' as a container\_format in dev-docs
  * Correcting description of image\_update API method
  * Add \_\_ne\_\_ built-in function
  * Replace "LOG.warn(\_" with "LOG.(\_LW"
  * Improving help text for public\_endpoint
  * Glance tasks lost configuration item conversion\_format
  * Use olso\_log and delay string interpolation while logging
  * Add check to limit maximum value of max\_rows
  * Remove old \`run\_tests\` script
  * Remove unused enable\_v3\_api config option
  * Adds virtual\_size to notifications
  * Deprecate use\_user\_token parameter
  * Updating comment in tests/unit/test\_migrations.py
  * Use assertGreater/Less/Equal instead of assertTrue(A \* B)
  * Resolve i18n and Sphinx issues in signature\_utils
  * Include registry\_client\_\* options in glance-scrubber.conf
  * Reuse encodeutils.to\_utf8()
  * Reuse jsonutils.dump\_as\_bytes()
  * Fix 500 status code when we add in "depend\_on" yourself
  * Fix \_wait\_on\_task\_execution()
  * Updating message for conversion\_format cfg\_opt
  * Remove glance\_store specific unit tests
  * Encode headers to launch glance v2 on mod\_wsgi
  * Add storage\_policy VMware driver option for flavors
  * Add properties\_target to Instance SW metadefs
  * Fix glance doesn't catches exception NotFound from glance\_store
  * Replace oslo\_utils.timeutils
  * Stop using tearDown in v1/test\_api.py
  * Rename glance-store to glance\_store
  * Move store config opt to glance\_store section
  * Port \_validate\_time() to Python 3
  * Support Unicode request\_id on Python 3
  * Unicode fix in BaseClient.\_do\_request() on py3
  * Fix glance.tests.unit.v1.test\_registry\_client
  * Fix 500 error when filtering by 'created\_at' and 'updated\_at'
  * Add documentation for configuring disk\_formats
  * Disallow user modifing ACTIVE\_IMMUTABLE of deactivated images
  * test: make enforce\_type=True in CONF.set\_override
  * Python3: fix glance.tests.unit.v2.test\_registry\_client
  * [docs] delete duplicated image\_status\_transition.png
  * Python3: fix glance.tests.unit.test\_migrations
  * Python3: fix test\_image\_data\_resource
  * Python3: fix test\_registry\_api
  * Python3: fix glance.tests.unit.v2.test\_images\_resource
  * Python 3: Fix glance.tests.unit.v2.test\_tasks\_resource
  * Python 3: fix test\_image\_members\_resource
  * Update style for signature\_utils class
  * Port v1.test\_registry\_api to Python 3
  * Port signature\_utils to Python 3
  * Rename semantic-version dep to semantic\_version
  * Port test\_cache\_manage to Python 3
  * Port test\_wsgi to Python 3
  * Rename glance-store dep to glance\_store
  * Remove glance\_store from exta requirements
  * utils: use oslo\_utils.uuidutils
  * fix a typo in show\_multiple\_locations help message
  * Port api test\_common to Python 3
  * Download forbidden when get\_image\_location is set
  * Download forbidden when get\_image\_location is set
  * add placeholder to ensure \_static directory exists
  * Change ignore-errors to ignore\_errors
  * Remove \`openstack' directory
  * Add missing function '\_validate\_limit'
  * Remove WARN log message from version\_negotiation
  * Make task\_time\_to\_live work
  * Add \_member\_ to property-protections-roles.conf.sample
  * Add unit tests for signature\_utils class
  * Fix spelling mistake in test\_images.py
  * Use oslo\_config PortOpt support
  * Setting default max\_request\_id\_length to 64
  * return request\_id in case of 500 error
  * Remove no longer used parameter (FEATURE\_BLACKLIST)
  * Fix error message's format in image\_member
  * Glance to handle exceptions from glance\_store
  * Allow ramdisk\_id, kernel\_id to be null on schema
  * Update glance\_store requirement to 0.7.1
  * Use oslo\_utils.encodeutils.exception\_to\_unicode()
  * Adds a rados\_connect\_timeout description
  * Fix the document bug in part of digest\_algorithm
  * Remove usage of assert\_called\_once in mocks
  * Add .eggs/\* to .gitignore
  * Remove unneeded OS\_TEST\_DBAPI\_ADMIN\_CONNECTION
  * Change default digest\_algorithm value to sha256
  * Adds os\_admin\_user to common OS image prop metadef
  * Validate size of 'min\_ram' and 'min\_disk'
  * Fix the db\_sync problem in 039 for db2
  * Add client\_socket\_timeout option
  * Remove duplicate creation of use\_user\_token
  * Fixed error message for negative values of min\_disk and min\_ram
  * Remove is\_public from domain layer
  * Fix test\_opts to not resolve requirements
  * Set filesystem\_store\_datadir in tests
  * VMware: vmware\_ostype should be enum
  * VMware: add VirtualVmxnet3 to hw\_vif\_model
  * Fixed glance.tests.unit.test\_artifacts\_plugin\_loader unit-test
  * glance-manage db load\_metadefs does not load all resource\_type\_associations
  * use is\_valid\_port from oslo.utils
  * Remove deprecated option db\_enforce\_mysql\_charset
  * Add sync check for models\_metadef
  * Use oslo\_config choices support
  * Remove en\_US translation
  * db\_export\_metadefs generates inappropriate json files
  * Remove is\_public from reserved attribute in v2
  * Clarified doc of public\_endpoint config option
  * Add detail description of image\_cache\_max\_size
  * Update vmware\_adaptertype metadef values
  * Redundant \_\_init\_\_ def in api.authorization.MetadefTagProxy
  * Fix copy-from when user\_storage\_quota is enabled
  * Move from oslo.db to oslo\_db
  * Move from oslo.config to oslo\_config
  * Improve documentation for glance\_stores
  * Move from oslo.utils to oslo\_utils
  * Add swift\_store\_cacert to config files and docs
  * rename oslo.concurrency to oslo\_concurrency
  * Removed obsolete db\_auto\_create configuration option
  * Move default\_store option in glance-api.conf
  * Remove \_i18n from openstack-common
  * Allow $OS\_AUTH\_URL environment variable to override config file value
  * Replace '\_' with '\_LI', '\_LE', '\_LW', '\_LC'
  * Move from using \_ builtin to using glance.i18n \_
  * Upgrade tests' mocks to match glance\_store
  * Make RequestContext use auth\_token (not auth\_tok)
  * change default value for s3\_store\_host
  * remove url-path from the default value of s3\_store\_host
  * Complete the change of adding public\_endpoint option
  * Update the vmware\_disktype metadefs values
  * Handle some exceptions of image\_create v2 api
  * Remove eventlet\_hub option
  * Add logging to image\_members and image\_tags
  * Adjust authentication.rst doc to reference "identity\_uri"
  * Adjust authentication.rst doc to reference "identity\_uri"
  * Use identity\_uri instead of older fragments
  * Remove db\_enforce\_mysql\_charset option for db\_sync of glance-manage
  * Refactor test\_migrations module
  * Fix missing space in user\_storage\_quota help message
  * Enforce using six.text\_type() over unicode()
  * Fixes logging in image\_import's main module
  * Refactor metadef ORM classes to use to\_dict instead of as\_dict
  * Just call register\_opts in tests
  * Use identity\_uri instead of older fragments
  * Enforce image\_size\_cap on v2 upload
  * Fix RBD store to use READ\_CHUNKSIZE
  * Use \`\_LW\` where appropriate in db/sqla/api
  * Add a \`\_retry\_on\_deadlock\` decorator
  * Use auth\_token from keystonemiddleware
  * Moving eventlet.hubs.use\_hub call up
  * Move \`location\`'s domain code out of glance.store
  * notifier: remove notifier\_strategy compat support
  * notifier: simply notifier\_strategy compat support
  * Improved coverage for glance.api.\*
  * Assign local variable in api.v2.image\_data
  * Add test for no\_translate\_debug\_logs hacking check
  * TaskTest:test\_fail() should use asserIstNone
  * Remove duplicated is\_uuid\_like() function
  * Removing duplicate entry from base\_conf
  * Replace unicode() for six.text\_type
  * To fixes import error for run\_tests.sh
  * Replace assert\* with more suitable asserts in unit tests
  * Sync latest network\_utils module from Oslo
  * user\_storage\_quota now accepts units with value
  * Catch loading failures if transport\_url is not set
  * Fix deprecation warning in test\_multiprocessing
* Fri Apr 14 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev8:
  * Fix and enable integration tests on py35
* Thu Apr 13 2017 cloud-devel@suse.de
- Update to version glance-15.0.0.0b2.dev7:
  * Updated from global requirements
  * Document the duties of the Release CPL
  15.0.0.0b1
* Tue Apr 11 2017 cloud-devel@suse.de
- Update to version glance-14.0.1.dev86:
  * Dev Docs for Writing E-M-C Migrations
* Mon Apr 10 2017 cloud-devel@suse.de
- Update to version glance-14.0.1.dev84:
  * Fix and enable two funcitonal tests on py35
* Sat Apr  8 2017 cloud-devel@suse.de
- Update to version glance-14.0.1.dev82:
  * Updated from global requirements
* Fri Apr  7 2017 cloud-devel@suse.de
- Update to version glance-14.0.1.dev81:
  * Update api-ref for Range request support
  * Do not serve partial img download reqs from cache
  * Add release note for bug 1670409
  * Accept Range requests and set appropriate response
* Thu Apr  6 2017 cloud-devel@suse.de
- Update to version glance-14.0.1.dev74:
  * Provide user friendly message for FK failure
  * Updated from global requirements
  * Fix experimental E-M-C migrations
  * Update man pages to Pike version and release date
* Wed Apr  5 2017 cloud-devel@suse.de
- Update to version glance-14.0.1.dev67:
  * Use cryptography instead of pycrypto
* Mon Apr  3 2017 cloud-devel@suse.de
- Update to version glance-14.0.1.dev65:
  * Updated from global requirements
  * Fix incompatibilities with WebOb 1.7
* Sat Mar 25 2017 tbechtold@suse.com
- Update to version glance-14.0.1.dev62:
  * Fix rendering of list elements
  * Replace master/slave usage in replication
  * Fix and enable remaining v1 tests on py35
  * Fix and enable test_cache_middleware test on py35
  * Invoke Monkey Patching for All Tests
  * Remove the remaining code after glare-ectomy
  * Invoke monkey_patching early enough for eventlet 0.20.1
  * correct "url" to "URL"
  * Fix Unsupported Language Test
  * Updated from global requirements
  * Use HostAddressOpt for opts that accept IP and hostnames
  * Remove glare leftovers from setup.cfg
  * Fix api-ref with Sphinx 1.5
  * Updated from global requirements
  * Restore man pages source files
  * Update test requirement
  * Glare-ectomy
  * Limit workers to 0 or 1 when using db.simple.api
  * Updated from global requirements
  * Restore Legacy Database Management doc
  * Open Pike for data migrations
  * Change identifiers in data migration tests
  * [docs] Removing docs from dev ref
  * Mock CURRENT_RELEASE for migration unit test
  * Cleanup 'ResourceWarning: unclosed file' in py35
  * remove useless EVENTLET_NO_GREENDNS
  * Image signature documentation modify key manager api class
- Remove glare packages. Glare is now a separated project
* Tue Feb 28 2017 cloud-devel@suse.de
- Update to version glance-14.0.1.dev16:
  * Fix up links to static content in sample-configuration
* Sat Feb 25 2017 cloud-devel@suse.de
- Update to version glance-14.0.1.dev15:
  * DB code refactor, simplify and clean-up
  * Change SafeConfigParser into ConfigParser
* Thu Feb 23 2017 cloud-devel@suse.de
- Update to version glance-14.0.1.dev13:
  * Fix scrubber test failing py35 gate
  14.0.0
  * Drop MANIFEST.in - it's not needed by pbr
* Sat Feb 18 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0rc2.dev11:
  * Update developer docs for rolling upgrades
  * Use https instead of http for git.openstack.org
* Thu Feb 16 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0rc2.dev7:
  * Updated from global requirements
  * Fix NameError in metadef_namespaces.py
* Wed Feb 15 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0rc2.dev5:
  * Fix brackets to suggest optionality
* Sat Feb 11 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0rc2.dev4:
  * Updated from global requirements
* Fri Feb 10 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0rc2.dev3:
  * Handling scrubber's exit in non-daemon mode
* Wed Feb  8 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0rc2.dev2:
  * Prepare for using standard python tests
* Sat Feb  4 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0rc2.dev1:
  * Update reno for stable/ocata
  14.0.0.0rc1
  * Refresh config files for Ocata RC-1
* Fri Feb  3 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b4.dev27:
  * Alembic migrations/rolling upgrades release note
  * Add expand/migrate/contract migrations for CI
  * Add expand/migrate/contract commands to glance-manage CLI
  * Refactor tests to use Alembic to run migrations
* Thu Feb  2 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b4.dev20:
  * Port Glance Migrations to Alembic
  * Refine migration query added with CI change
  * Update deprecated show_multiple_locations helptext
* Wed Feb  1 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b4.dev14:
  * Correct 2.5 minor version bump release note
  * Update api-ref for image visibility changes
  * refactor glare plugin loader tests to not mock private methods of stevedore
  * Add release note for image visibility changes
* Mon Jan 30 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b4.dev7:
  * Hack to support old and new stevedore
* Sun Jan 29 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b4.dev6:
  * do not mock private methods of objects from libraries
* Sat Jan 28 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b4.dev4:
  * Update api-ref for partial download requests
  * Bump minor API version
* Fri Jan 27 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b4.dev1:
  * Updated from global requirements
  14.0.0.0b3
  * Add image update tests for is_public
* Thu Jan 26 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev45:
  * Enable python3.5 testing
* Wed Jan 25 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev43:
  * Eliminate reference to metadefs 'namespace_id'
  * Updated from global requirements
  * Fix regression introduced by Community Images
* Fri Jan 20 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev40:
  * Implement and Enable Community Images
* Wed Jan 18 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev38:
  * Update to "disallowed minor code changes"
  * Updated from global requirements
* Tue Jan 17 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev35:
  * Adjust test suite for new psutil versions
* Wed Jan 11 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev33:
  * Update dev docs to include 'vhdx' disk format
* Tue Jan 10 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev32:
  * Add ploop to supported disk_formats
* Sat Jan  7 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev30:
  * Image signature documentation modify barbican auth_endpoint
* Fri Jan  6 2017 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev29:
  * Handling HTTP range requests in Glance
* Fri Dec 30 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev28:
  * Remove obsolete swift links
* Wed Dec 28 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev27:
  * Correct url in doc source
* Sat Dec 24 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev26:
  * Updated from global requirements
* Fri Dec 23 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev25:
  * Fix some typos in api-ref
* Thu Dec 22 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev23:
  * Updated from global requirements
  * Update sample config files for Ocata-3
  * Expand hypervisor_type meta data with Virtuozzo hypervisor
  * Add libvirt image metadef for hw_pointer_model
* Wed Dec 21 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev17:
  * Update tox configuration file to reduce duplication
  * Editing release note for location update patch
  * Change cfg.set_defaults into cors.set_defaults
  * Allow purging of records less than 1 day old
  * Python3: fix glance.tests.functional.v2.test_images
  * Python 3: fix glance.tests.functional.v1.test_misc
  * Python3: fix glance.tests.functional.test_scrubber
  * Python3: fix logs/glance.tests.functional.test_healthcheck_middleware
  * Python3: Fix glance.tests.functional.test_glance_replicator
  * Python3: Fix glance.tests.functional.test_bin_glance_cache_manage
* Tue Dec 20 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev6:
  * Python 3: fix glance.tests.functional.db.test_sqlalchemy
  * Python3: fix test_client_redirects.py
* Sat Dec 17 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev4:
  * Remove v3 stub controller
* Fri Dec 16 2016 tbechtold@suse.com
- Update to version glance-14.0.0.0b3.dev2:
  * Updated from global requirements
* Thu Dec 15 2016 tbechtold@suse.com
- config cleanup
* Thu Dec 15 2016 aplanas@suse.com
- Create /etc/glance/glance.conf.d
* Thu Dec 15 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b3.dev1:
  14.0.0.0b2
  * Skipping tests for location 'add', 'replace' on 'queued' images
  * Add working functional tests to tox.ini
  * Use upper constraints for all jobs in tox.ini
* Thu Dec  8 2016 aplanas@suse.com
- systemd: remove Wants from services.
* Thu Dec  8 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b2.dev18:
  * Restrict location updates to active, queued images
* Wed Dec  7 2016 tbechtold@suse.com
- Remove --config-dir and --config-file switches from the services.
  oslo.config has good defaults so there is no need to explicitly
  mention the config files.
* Tue Dec  6 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b2.dev16:
  * Updated from global requirements
  * Add alt text for badges
  * Correct releasenote "Prepare for oslo.log 3.17.0"
* Sat Dec  3 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b2.dev11:
  * Updated from global requirements
  * Updated from global requirements
* Thu Dec  1 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b2.dev9:
  * Show team and repo badges on README
* Wed Nov 30 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b2.dev7:
  * Prepare for oslo.log 3.17.0
* Tue Nov 29 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b2.dev5:
  * IPv6 fix in Glance for malformed URLs
* Wed Nov 23 2016 cloud-devel@suse.de
- Update to version glance-14.0.0.0b2.dev4:
  * Remove uneccessary "in" from CONTRIBUTING.rst
  14.0.0.0b1
  * Added unit tests for disabled notifications in Notifier
  * Update api-ref to add newly supported 'vhdx' disk format option
* Wed Nov 16 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev88:
  * Updated from global requirements
* Tue Nov 15 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev87:
  * Remove mox3 in test-requirement.txt
* Sat Nov 12 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev85:
  * Update api-ref with 409 response to image update
  * Do not use service catalog for cache client
  * Correctly point to Task Statuses from Tasks doc
* Thu Nov 10 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev80:
  * Updated from global requirements
  * Fix Domain Model code example
* Wed Nov  9 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev77:
  * Added overwrite warning for db_export_metadefs
  * Allow specifying OS_TEST_PATH (to reduce tests ran)
  * Add DeprecationWarning in test environments
* Tue Nov  8 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev71:
  * Updated from global requirements
* Sun Nov  6 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev70:
  * ping_server: Always close the socket
* Sat Nov  5 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev68:
  * Updated from global requirements
  * change the example URLs in api-ref for Glance
* Mon Oct 31 2016 tbechtold@suse.com
- Switch to systemd service files
- Add empty /etc/glance/conf.d/common
- Fix tmpfiles creation
- Create sub-packages for api, glare and registry service
* Wed Oct 26 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev65:
  * Updated from global requirements
  * Extracted HTTP response codes to constants in tests
* Sat Oct 22 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev62:
  * Extracted HTTP response codes to constants
* Fri Oct 21 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev60:
  * Fixed indentation
* Thu Oct 20 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev59:
  * Updated from global requirements
  * Drop unused import cfg
* Tue Oct 18 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev56:
  * Update .coveragerc after the removal of openstack directory
  * Updated from global requirements
  * Imported Translations from Zanata
* Fri Oct 14 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev51:
  * Add more resource url in readme.rst
  * Updated from global requirements
* Thu Oct 13 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev48:
  * Cleanup newton release Notes
* Tue Oct 11 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev46:
  * Imported Translations from Zanata
* Sat Oct  8 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev45:
  * Imported Translations from Zanata
  * Remove redundant word
  * Enable release notes translation
  * Updated from global requirements
  * TrivialFix: Remove unused variable
  * Remove self.__dict__ for formatting strings
* Fri Oct  7 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev36:
  * Updated from global requirements
  * Fix typo: remove redundant 'the'
* Thu Oct  6 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev32:
  * [api-ref] configure LogABug feature
* Sun Oct  2 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev30:
  * Fix using filter() to meet python2,3
* Sat Oct  1 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev29:
  * dev-docs: mark v1 as deprecated
  * Updated from global requirements
  * api-ref: deprecate images v1 api
  * api-ref: add versions history
* Fri Sep 30 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev22:
  * Updated from global requirements
* Wed Sep 28 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev21:
  * Correct releasenote for Ib900bbc05cb9ccd90c6f56ccb4bf2006e30cdc80
  * Updated from global requirements
  * Update CONTRIBUTING.rst
* Tue Sep 27 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev16:
  * Adding constraints around qemu-img calls
* Tue Sep 27 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev14:
  * Correct the order of parameters in assertEqual()
  * [api-ref] Remove temporary block
* Sat Sep 24 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev12:
  * Fixing inconsistency in Glance store names
  * Updated from global requirements
  * Add note to docs on release notes prelude section
* Fri Sep 23 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev8:
  * Remove unused oslo.service requirement
* Thu Sep 22 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev7:
  * Fix incorrect call for _gen_uuid
* Wed Sep 21 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0rc2.dev5:
  * Update description of image_destroy method
  * Update reno for stable/newton
  13.0.0.0rc1
  * Dev-docs: command in code block for refresh config
  * Fix five typos on doc
* Fri Sep 16 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b4.dev12:
  * Complete and update Newton release notes
  * Bump up Glance API minor version to 2.4
* Wed Sep 14 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b4.dev8:
  * Keep consistent order for regenerated configs
* Sat Sep 10 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b4.dev6:
  * Updated from global requirements
  * Fix cursive named arguments
* Fri Sep  9 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b4.dev4:
  * Fix nits from commit that introduces cursive
* Thu Sep  8 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b4.dev2:
  * Attempt to not set location on non active or queued image
* Mon Sep  5 2016 tbechtold@suse.com
- Update to version glance-13.0.0.0b4.dev1:
  * Fix a small markup typo
  13.0.0.0b3
  * Regenerate config files for Newton
  * Improving help text for common-config opts
  * Improving help text for data access API option
  * Improving help text for Glance common-config opts
  * Remove DB downgrade
  * Release note for glance config opts
  * Improve help text of glance config opts
  * Improving help text for WSGI server conf opts
  * Use cursive for signature verification
  * Updated from global requirements
  * Improving help text for metadefs config option
  * Improve the help text for registry client opts
  * Improving help text for send_identity_headers opt
  * Remove unused requirements
  * Deprecate `show_multiple_locations` option
  * Deprecate the Images (Glance) v1 API
  * Wrap text in sample configuration files at 80
* Tue Aug 30 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev133:
  * Remove "Services which consume this" section
  * Image signature base64 don't wrap lines
* Sat Aug 27 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev129:
  * Improving help text of v1/v2 API & Registry opts
  * Improve help text of scrubber daemon option
  * Improving help text for RPC opt
  * Improving help text for image conversion_format
  * Updated from global requirements
* Fri Aug 26 2016 aplanas@suse.com
- Revert generate PID file for systemd (bsc#991985)
* Fri Aug 26 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev120:
  * Updated from global requirements
  * TrivialFix: Remove cfg import unused
  * Improving help text for store_type_preference opt
  * Improving help text for Notifier opts
  * Removing deprecated variable aliases from oslo_messaging
  * Improve help text of registry server opts
  * Add CPU thread pinning to metadata defs
* Thu Aug 25 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev106:
  * Get ready for os-api-ref sphinx theme change
  * Don't use config option sqlite_db
* Thu Aug 25 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev102:
  * Improve help text of scrubber opts
* Wed Aug 24 2016 aplanas@suse.com
- Generate PID file for systemd (bsc#991985)
* Wed Aug 24 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev100:
  * Correct link to image properties
  * Improve help text of quota opts
* Sun Aug 21 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev96:
  * Add registry_client_opts to glance-cache.conf.sample
* Sat Aug 20 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev94:
  * Remove references of s3 store driver
* Fri Aug 19 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev92:
  * Updated from global requirements
  * Stop stack tracing on 404s
  * Index to generate doc page for refreshing-configs
* Thu Aug 18 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev87:
  * change the example URLs in dev-docs for Glance
  * Refresh some config files based on bug fixes
* Wed Aug 17 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev83:
  * Add example for diff between assert true and equal
* Tue Aug 16 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev81:
  * Add guideline to refresh config files shipped with source
* Sat Aug 13 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev80:
  * Updated from global requirements
  * Use more specific asserts in unit tests
* Fri Aug 12 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev77:
  * Add test class to versions tests
* Thu Aug 11 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev75:
  * Updated from global requirements
  * api-ref: correct versions response example
  * Remove deprecated test utility
* Tue Aug  9 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev70:
  * Updated from global requirements
  * Updated from global requirements
  * Fix use of etc. in metadefs docs
  * Improving help text for location_strategy opt
  * Add a requirements guidelines to docs
  * Updated from global requirements
  * Version negotiation api middleware to include v2.3
  * Add release notes for newton-1
  * Some migrations tests incorrectly ref S3 for Swift
  * Remove extraneous ws in architecture docs
  * Generate and include sample config as part of docs
  * Improving help text for proprty utils opts
  * Updated from global requirements
  * Improving help text for swift_store_utils opts
  * Improving help text for taskflow executor opts
* Mon Aug  8 2016 tbechtold@suse.com
- Generate sample config files during build
* Tue Aug  2 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev44:
  * cache_manage: fix a print bug in exit main
  * replicator: dump: Display more info
  * replicator: livecopy: Display more info
  * Updated from global requirements
  * Add ova to container format doc to rally plugin
  * Add 'vhdx' disk format
  * Add 'ova' as a container_format in dev-docs
  * Add check to limit maximum value of max_rows
* Thu Jul 28 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev30:
  * Update sqlalchemy-migrate url
  * Replace OpenStack LLC with OpenStack Foundation
  * Making Forbidden Exception action oriented
* Wed Jul 27 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev24:
  * Minor tweak to release note documentation
  * api-ref: Replace image-update response example
  * api-ref: Refresh images schemas
  * Correcting description of image_update API method
  * Make docs copyright consistent
  * Add LOG.warning to Disallowed minor changes
* Sun Jul 24 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev12:
  * WADL to RST migration (part 2 - images)
* Sat Jul 23 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev10:
  * Updated from global requirements
  * glance-replicator: size: Handle no args better
  * Contribution doc change for spec-lite
* Fri Jul 22 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev7:
  * Updated from global requirements
* Fri Jul 15 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b3.dev6:
  * Improving help text for context middleware opts
  13.0.0.0b2
  * Replace "LOG.warn(_" with "LOG.(_LW"
  * Cleanup i18n marker functions to match Oslo usage
  * Remove unused LOG to keep code clean
  * Correct reraising of exception
* Thu Jul 14 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b2.dev65:
  * Add __ne__ built-in function
  * Use oslo.context features
  * glance-replicator: compare: Show image name in msg
* Wed Jul 13 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b2.dev59:
  * Updated from global requirements
  * WADL to RST migration (part 2 - metadefs)
* Tue Jul 12 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b2.dev56:
  * Perform a cleanup of configuring.rst
* Mon Jul 11 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b2.dev54:
  * replicator: size: Display human-readable size
* Sun Jul 10 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b2.dev52:
  * Nitpick spell change
* Sat Jul  9 2016 cloud-devel@suse.de
- Update to version glance-13.0.0.0b2.dev50:
  * Improving help text for public_endpoint
  * Add image signature verification metadefs
* Thu Jul  7 2016 aplanas@suse.de
- Update to version glance-13.0.0.0b2.dev46:
  * Fix duplicated osprofile config for registry
  * Return 400 when name is more than 255 characters
  * Use MultiStrOpt instead of ListOpt for args
  * Updated from global requirements
  * Add signed images documentation
  * Glance tasks lost configuration item conversion_format
  * Update to Glance Contributor's docs
  * WADL to RST migration (part 2 - tasks)
  * Updated from global requirements
  * Updated from global requirements
  * WADL to RST migration (part 1)
  * Add documentation about generating release notes
  * Change default policy to admin
  * Fix bug Swift ACL which disappears on Glance v1 images
  * Do not set header if checksum doesn't exist
  * Updated from global requirements
  * Fixes the use of dates when listing images
  * Use olso_log and delay string interpolation while logging
  * Add in missing log hints
  * Use http-proxy-to-wsgi middleware from oslo.middleware
  * Updated from global requirements
  * Imported Translations from Zanata
  * Add a soft delete functionality for tasks
  * Update man pages to current version and dates
  * Incorrect title for Outbound Peak
  * Updated from global requirements
  13.0.0.0b1
  * Remove redundant store config from registry sample
  * Remove TODOs from deprecated "sign-the-hash"
  * Updated from global requirements
  * Fix import of profiler options
  * Updated from global requirements
  * Remove old `run_tests` script
  * Fix possible race conditions during status change
* Mon Jun 27 2016 jsuchome@suse.com
- Add systemd service macros (bnc#986415)
  systemd v228 has a separate generator for generating the service
  files from the init scripts, and daemon-reload is needed during
  package installation
* Sun May 29 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev84:
  * Updated from global requirements
  * Use OSprofiler options consolidated in lib itself
  * Remove unnecessary executable permissions
* Sat May 28 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev78:
  * Remove verbose option from glance tests
  * Raise exception when import without properties
  * Excluded the 'visibility' from protected artifact fields
* Wed May 25 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev72:
  * Normalize the options use singele quotes
* Tue May 24 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev70:
  * Updated from global requirements
* Fri May 20 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev69:
  * Updated from global requirements
  * Allow tests to run when http proxy is set
* Thu May 19 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev66:
  * Updated from global requirements
* Fri May 13 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev65:
  * Correct some misspelt words in glance
  * Clarify language used in glanceapi future section
  * Give helpful error in tests if strace is missing
* Wed May 11 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev60:
  * Images APIs: The Future
* Mon May  9 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev58:
  * Remove unnecessary executable privilge of unit test file
  * Updated from global requirements
  * Improve help text of image cache opts
  * Return BadRequest for 4 byte unicode characters
* Mon May  9 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev51:
  * Functional test comparing wrong items
  * Updated from global requirements
* Fri Apr 22 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev49:
  * Updated from global requirements
  * Remove deprecated "sign-the-hash" approach
* Thu Apr 21 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev46:
  * Imported Translations from Zanata
  * Updated from global requirements
  * Adding detailed alt text to images for accessibility
  * Fix doc build if git is absent
  * use os-testr instead of testr
* Sun Apr 17 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev38:
  * Corrected section underline
* Sat Apr 16 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev36:
  * Log when task is not configured properly
* Thu Apr 14 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev34:
  * Changed the spelling of opsrofiler to osprofiler
  * Increase max wait time, avoid racy failure in gate
  * Use messaging notifications transport instead of default
* Wed Apr 13 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev28:
  * Updated from global requirements
  * Add store opts to scrubber and cache sample conf
  * Store URI must start with the expected  URI scheme
  * Consider  @,! in properties protection rule as a configuration error
  * Refactors stores to be stateful:
  * Adds authentication middleware support in glance (integration to keystone will be performed as a piece of middleware extending this and committed to the keystone repository).  Also implements private images.  No limited-visibility shared image support is provided yet
  * How in the world did I manage to forget this?  *sigh*
  * Added new disk_format type of 'iso'.  Nova can use this information to identify images that have to be booted from a CDROM
  * * Adds functional test that works with Amazon S3 * Fixes parsing of "S3 URLs" which urlparse utterly barfs on because   Amazon stupidly allows forward slashes in their secret keys * Update /etc/glance-api.conf for S3 settings
  * Add tests for 'iso' image type. Remove hard coding of next available image id in tests.  This prevents new test images from being added to the set generated by tests.unit.stubs.FakeDatastore
  * resolve merge conflicts
  * Changes to database schema required to support images larger than 2Gig on MySQL.  Does not update the migration scripts
  * Updates to the Registry API such that only external requests to   update image properties purge existing properties. The update_image   call now contains an extra flag to purge_props which is set to   True for external requests but False internally
  * Fixes passing of None values in metadata by turning them into strings.  Also fixes the passing of the deleted column by converting it to and from a bool.  The test for passing metadata was updated to include these values
  * Fixes client update_image to work like create_image.  Also fixes some messed up exceptions that were causing a try, except to reraise
  * Adds facilities for configuring Glance's servers via     configuration files
  * Fix all Glance's pep8 problems
  * Fixes a number of things that came up during initial     coding of the admin tool:
  * documentation cleanup and matching to other OpenStack projects.  Glance is no longer the red-headed documentation stepchild in OpenStack..
  * Merges Glance API with the registry API: * Makes HEAD /images/<ID> return metadata in headers * Make GET /images/<ID> return image data with metadata   in headers Updates docs some (more needed)
  * Just some small cleanups, fixing:   * Swapped port numbers (Parallax Port <=> Teller port)   * Removing extraneous routes in Teller API   * Adding required slashes to do_request
  * * Changes Teller API to use REST with opaque ID sent in       API calls instead of a "parallax URI". This hides the       URI stuff behind the API layer in communication between       Parallax and Teller.     * Adds unit tests for the only complete Teller API call so       far: GET images/<ID>, which returns a gzip'd string of       image data
  * * Changes Teller API to use REST with opaque ID sent in   API calls instead of a "parallax URI".  This hides the   URI stuff behind the API layer in communication between   Parallax and Teller. * Adds unit tests for the only complete Teller API call so   far: GET images/<ID>, which returns a gzip'd string of   image data
  * This patch:   * Decouples Controller for ParallaxAdapter implementation by adding generic RegistryAdapter and providing a lookup function   * Adds base model attributes to Parallax's JSON (created_at, etc)
  * This patch:   * pulls in a number of useful libraries from Nova under the common/ path (we can factor those out to a shared library in Bexar-release)   * Defines the models in common.db.sqlalchemy.models.py (this should be factored out into the parallax package soon)   * Adds the parallax api-server under /bin (if PyPI was used to pull python-daemon and python-lockfile, you may need to apply a patch I have against it)
* Tue Apr 12 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev25:
  * Add wsgi options to the sample options
  * Removed one extra enter key
* Fri Apr  8 2016 cloud-devel@suse.de
- Update to version glance-12.0.1.dev21:
  * Modified message of exception and log
  * Given space in between two words
  * Updated from global requirements
  * Fix doc-strings warnings and errors
  12.0.0
  * Imported Translations from Zanata
  * Imported Translations from Zanata
  * Imported Translations from Zanata
  * Imported Translations from Zanata
  * Imported Translations from Zanata
  * Imported Translations from Zanata
  * Update .gitreview for stable/mitaka
* Thu Apr  7 2016 cloud-devel@suse.de
- Update to version glance-12.0.0.0rc2.dev25:
  * Updated from global requirements
  * Update the Administrator guide links with new ones
  * Imported Translations from Zanata
  * Fix db purge type validation
* Wed Apr  6 2016 cloud-devel@suse.de
- Update to version glance-12.0.0.0rc2.dev18:
  * Use roles attribute from oslo context
* Tue Apr  5 2016 cloud-devel@suse.de
- Update to version glance-12.0.0.0rc2.dev16:
  * Updated from global requirements
  * Add 'Documentation' section to 'Contributing' docs
* Thu Mar 31 2016 cloud-devel@suse.de
- Update to version glance-12.0.0.0rc2.dev12:
  * Fix typos in Glance files
* Tue Mar 29 2016 cloud-devel@suse.de
- Update to version glance-12.0.0.0rc2.dev11:
  * Handle SSL termination proxies for version list
* Sat Mar 26 2016 cloud-devel@suse.de
- Update to version glance-12.0.0.0rc2.dev9:
  * Update reno for stable/mitaka
* Fri Mar 25 2016 cloud-devel@suse.de
- Update to version glance-12.0.0.0rc2.dev7:
  * Copy the size of the tag set
* Tue Mar 22 2016 cloud-devel@suse.de
- Update to version glance-12.0.0.0rc2.dev5:
  * fix docstring warnings and errors
  * Fix link to <configuring> document
  * Update the configuration doc
* Fri Mar 18 2016 cloud-devel@suse.de
- Update to version glance-12.0.0.0rc2.dev2:
  * Imported Translations from Zanata
* Thu Mar 17 2016 cloud-devel@suse.de
- Update to version glance-12.0.0.0rc2.dev1:
  * Fixed typos in two comments
  12.0.0.0rc1
* Wed Mar 16 2016 tbechtold@suse.com
- Update to version glance-12.0.0.0b4.dev52:
  * Reject bodies for metadef commands
  * glance-manage db purge failure for limit
- Adjust Requires and BuildRequires
* Tue Mar 15 2016 cloud-devel@suse.de
- Update to version glance-12.0.0.0b4.dev48:
  * revert warnerrors before gate breaks
  * Imported Translations from Zanata
  * Catch exceptions.HasSnapshot() from delete image in rbd driver
* Sun Mar 13 2016 cloud-devel@suse.de
- Update to version glance-12.0.0.0b4.dev42:
  * Imported Translations from Zanata
* Sat Mar 12 2016 cloud-devel@suse.de
- Update to version glance-12.0.0.0b4.dev41:
  * register the config generator default hook with the right name
  * Remove unused enable_v3_api config option
  * Imported Translations from Zanata
  * Test tag against schema to check length
* Fri Mar 11 2016 tbechtold@suse.com
- Install /etc/glance/glance-glare.conf
- Install /etc/glance/ovf-metadata.json.sample
- Install /etc/glance/glance-glare-paste.ini
- Install /usr/bin/glance-glare
- Adjust BuildRequires
* Thu Mar 10 2016 tbechtold@suse.com
- Update to version glance-12.0.0.0b4.dev34:
  * Remove state transition from active to queued
  * Imported Translations from Zanata
  * Updated the wording in the database architecture docs
  * Update the config files
  * Imported Translations from Zanata
  * Adds virtual_size to notifications
  * Update configuring of Cinder store
  * Add debug testenv in tox
  * Fix levels of Swift configuration documentation
  * no module docs generated
  * Deprecate use_user_token parameter
  * Creating or updating a image member in a list causes 500
  * Updated from global requirements
  * Updating comment in tests/unit/test_migrations.py
  * Fix update all props when you delete image
  12.0.0.0b3
  * Fix location update
  * Moved CORS middleware configuration into oslo-config-generator
  * Use assertGreater/Less/Equal instead of assertTrue(A * B)
  * New metadata definitions from CIM
  * Add support for DSA signatures
  * Fix message formatting in glance-manage purge
  * Updated from global requirements
  * Remove unused pngmath sphinx extension
  * Do not use constraints for venv
  * Fix BaseException.message deprecation warnings
  * Remove py33 from tox envlist
- Adjust Requires according to requirements.txt
* Mon Feb 29 2016 johannes.grassler@suse.com
- Ensure glance services are started after openstack-keystone (bsc#955786)
* Mon Dec 28 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev52:
  * Remove unused logging import
* Fri Dec 25 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev51:
  * assertIsNone(val) instead of assertEqual(None,val)
  * Deprecated tox -downloadcache option removed
* Thu Dec 24 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev47:
  * Fix glance doesn't catches exception NotFound from glance_store
  * Update the cache middleware flavor guideline
* Wed Dec 23 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev43:
  * Updated from global requirements
  * Add sign-the-hash deprecation warning
* Mon Dec 21 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev40:
  * Added CORS support to Glance
* Sun Dec 20 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev38:
  * Add db purge command
* Sat Dec 19 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev36:
  * Wait all wsgi server completion for worker exit
  * Fix model sync for SQLite
* Sat Dec 12 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev34:
  * Replace oslo_utils.timeutils
* Fri Dec 11 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev33:
  * Import i18n functions directly
* Thu Dec 10 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev31:
  * Remove iso8601 dependency
  * Updated from global requirements
  * Remove artifact entry point
* Wed Dec  9 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev26:
  * Fix default value with postgreSQL
* Tue Dec  8 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev24:
  * Change the format of some inconsistent docstring
* Mon Dec  7 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev22:
  * Updated from global requirements
  * Run py34 env first when launching tests
* Sun Dec  6 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev18:
  * Stop using tearDown in v1/test_api.py
  * Format log messages correctly
* Sat Dec  5 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev15:
  * Capitalize 'glance' in db.rst
  * Fix return 200 status code when we operate with nonexistent property
  * Rename glance-store to glance_store
  * Automated bandit checks in glance
  * Unicode fix in BaseClient._do_request() on py3
  * Fix incorrect task status with wrong parameter
  * Change the default notification exchange to glance
  * Location add catch bad Uri
* Fri Dec  4 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev5:
  * Remove version from setup.cfg
  * Add the Docker container format
* Thu Dec  3 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.0b2.dev1:
  * Move store config opt to glance_store section
  12.0.0.0b1
* Wed Dec  2 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev148:
  * Port _validate_time() to Python 3
  * Updated from global requirements
  * Document contribution guidelines
  * Remove anyjson useless requirement
* Mon Nov 30 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev140:
  * Support Unicode request_id on Python 3
* Sat Nov 28 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev138:
  * Updated from global requirements
  * OpenStack typo
* Fri Nov 27 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev135:
  * Updated from global requirements
  * Fix glance.tests.unit.v1.test_registry_client
  * Fix sample Rally plugin
  * V1: Fix bad dates returning 500
  * Add -constraints for CI jobs
* Thu Nov 26 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev125:
  * force releasenotes warnings to be treated as errors
  * Fix 500 error when filtering with specified invalid operator
  * Add documentation for configuring disk_formats
  * V1: Stop id changes after the image creation
  * test: make enforce_type=True in CONF.set_override
* Wed Nov 25 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev116:
  * Fix 500 error when filtering by 'created_at' and 'updated_at'
  * Update os.path.remove as it does not exist
* Tue Nov 24 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev112:
  * Disallow user modifing ACTIVE_IMMUTABLE of deactivated images
* Mon Nov 23 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev110:
  * [docs] Update description of Glance-Swift conf options
* Fri Nov 20 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev108:
  * [docs] delete duplicated image_status_transition.png
* Fri Nov 20 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev106:
  * [docs] Update Glance architecture image
* Thu Nov 19 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev105:
  * Python3: fix glance.tests.unit.v2.test_registry_client
  * Python3: fix test_image_data_resource
  * Update style for signature_utils class
* Wed Nov 18 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev99:
  * Support new v2 API image filters
  * Reactivating admin public image returns 500
  * Python3: fix glance.tests.unit.test_migrations
* Tue Nov 17 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev93:
  * Remove todo to remove /versions
  * Remove unused exceptions from glance
  * Rename semantic-version dep to semantic_version
* Fri Nov 13 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev87:
  * Python3: fix test_registry_api
  * Updated from global requirements
  * Python3: fix glance.tests.unit.v2.test_images_resource
  * Python 3: fix test_image_members_resource
  * Fix content type for Forbidden exception
  * Fix error when downloading image status is not active
* Thu Nov 12 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev75:
  * Remove default=None for config options
* Wed Nov 11 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev73:
  * add "unreleased" release notes page
  * Python 3: Fix glance.tests.unit.v2.test_tasks_resource
* Tue Nov 10 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev69:
  * Add tasks info to glance documentation
* Sat Nov  7 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev67:
  * Port signature_utils to Python 3
* Fri Nov  6 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev65:
  * Add reno for release notes management
  * Allow owner to be set on image create
* Wed Nov  4 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev63:
  * Add subunit.log to gitignore
  * Use dict comprehension
* Tue Nov  3 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev59:
  * Updated from global requirements
* Wed Oct 28 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev58:
  * Port v1.test_registry_api to Python 3
* Sat Oct 24 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev56:
  * Rename glance-store dep to glance_store
  * Remove glance_store from exta requirements
  11.0.0
  * Add 'deactivated' status to image schema
  * Add testresources and testscenarios used by oslo.db fixture
  11.0.0.0rc2
  * Cleanup chunks for deleted image if token expired
  * Download forbidden when get_image_location is set
  * Catch NotAuthenticated exception in import task
  * Imported Translations from Zanata
  * Return missing authtoken options
* Fri Oct 23 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev116:
  * Remove requests to example.com during unit testing
  * Imported Translations from Zanata
  * Typo fix
  * Remove the duplicate file path created by sphinx build
* Thu Oct 22 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev109:
  * Port script utils to Python 3
  * Updated from global requirements
  * Port test_cache_manage to Python 3
  * Port test_wsgi to Python 3
  * Refactoring exceptions
  * Use oslo_config PortOpt support
* Tue Oct 20 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev99:
  * Port async tests to Python 3
  * [docs] Adds new image status - deactivated
* Mon Oct 19 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev95:
  * Fixed registry invalid token exception handling
  * utils: use oslo_utils.uuidutils
  * Pass CONF to logging setup
  * Catch InvalidImageStatusTransition error
  * Port rpc and wsgi to Python 3
  * Add _member_ to property-protections-roles.conf.sample
* Sun Oct 18 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev84:
  * Updated from global requirements
  * utils: remove unused functions in glance.utils
* Sat Oct 17 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev80:
  * Fix incorrect Glance image metadata description
  * Updated from global requirements
  * Add more tests which pass on Python 3
  * Show the file name when there is an error loading an image metadef file
* Thu Oct 15 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev73:
  * Cause forbidden when deactivating image(non-admin)
  * Updated from global requirements
  * Don't allow queries with 'IN' predicate with an empty sequence
  * Bodies that are not dicts or lists return 400
  * Decrease test failure if second changes during run
  * fix a typo in show_multiple_locations help message
* Wed Oct 14 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev61:
  * config: remove default lockutils set
  * Updated from global requirements
  * Add testresources and testscenarios used by oslo.db fixture
  * Fix 409 response when updating an image by removing read-only property
  * Imported Translations from Zanata
* Tue Oct 13 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev53:
  * Add 'deactivated' status to image schema
  * Fix the bug of "Error spelling of a word"
* Sat Oct 10 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev51:
  * Change string generation mechanism for info logging
  * Add swiftclient to test-requirements
* Fri Oct  9 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev48:
  * Port api test_common to Python 3
* Thu Oct  8 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev46:
  * Imported Translations from Zanata
  * Updated from global requirements
  * Download forbidden when get_image_location is set
  * tell pbr to tell sphinx to treat warnings as errors
  * add placeholder to ensure _static directory exists
  * add the man pages to the toctree
  * escape underline introducing a spurrious link reference
  * utils: stop building useless closure
  * Add missing function '_validate_limit'
  * Port common.utils to Python 3
  * Port store image to Python 3
  * Port replicator to Python 3
  * Port glance.db to Python 3
  * Port image cache to Python 3
  * Fix Python 3 issues in glance.tests.unit.common
* Mon Oct  5 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev25:
  * do not indent include directives
  * add missing document to toctree
* Mon Oct  5 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev21:
  * Fix mutable defaults in tests
* Sat Oct  3 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev19:
  * An explicit check for the presence of a property
  * fix restructuredtext formatting errors
  * Cleanup chunks for deleted image if token expired
  * Catch NotAuthenticated exception in import task
  * Fix 501 error when accessing the server with a non-existent method
* Fri Oct  2 2015 vuntz@suse.com
- Add requires on qemu-tools (for qemu-img) to openstack-glance,
  due to support for image conversion.
* Fri Oct  2 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev10:
  * Add Large pages meta definition
* Thu Oct  1 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev8:
  * Fix wrong parameters order in Task
* Wed Sep 30 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev7:
  * Return missing authtoken options
* Tue Sep 29 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev5:
  * Imported Translations from Zanata
  11.0.0.0rc1
  * Remove `openstack' directory
  * Fix order of arguments in assertEqual
* Sun Sep 27 2015 cloud-devel@suse.de
- Update to version glance-12.0.0.dev65:
  * Open Mitaka development
  * Cleanup of Translations
  * Remove redundant requirements.txt from tox
  * Updated from global requirements
  * Update Glance example configs to reflect Liberty
  * Fix server start ping timeout for functional tests
* Thu Sep 24 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b4.dev55:
  * Imported Translations from Zanata
  * Setting default max_request_id_length to 64
* Wed Sep 23 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b4.dev52:
  * Prevent image status being directly modified via v1 (bsc#945994, CVE-2015-5251)
  * Fixed the output of list artifacts API calls
  * Prevent extraneous log messages and stdout prints
  * Add unit tests for signature_utils class
  * Fixed non-owner write-access to artifacts
  * Fixed an HTTP 500 on artifact blob upload
  * reuse the deleted image-member before create a new image-member
  * Use dictionary literal for dictionary creation
  * Remove duplicate name attribute
* Tue Sep 22 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b4.dev39:
  * Change ignore-errors to ignore_errors
  * [Glance Developer Guide] Grammar edits
  * Allow to filter artifacts by range
  * Fixed version unequality artifact filtering
  * Artifacts are now properly filtered by dict props
* Sat Sep 19 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b4.dev33:
  * Imported Translations from Zanata
  * Fixes the possibility of leaving orphaned data
  * Remove WARN log message from version_negotiation
  * Scrub images in parallel
* Thu Sep 17 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b4.dev25:
  * Domain model section
* Tue Sep 15 2015 tbechtold@suse.com
- Update to version glance-11.0.0.0b4.dev23:
  * Make task_time_to_live work
- Adjust Requires according to requirements.txt
* Tue Sep 15 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b4.dev21:
  * Incorrect permissions on database migration file
  * Scrubber to communicate with trustedauth registry
* Sat Sep 12 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b4.dev17:
  * Glance metadef tables need unique constraints
  * Don't return 300 when requesting /versions
  * List creation could be rewritten as a list literal
* Fri Sep 11 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b4.dev14:
  * Corrected hyperlink in metadefs documentation
  * Remove pointless tests comparing opts against list
  * Remove old traces of the oslo-incubator
  * Updated from global requirements
  * Use oslo utils to encode exception messages
  * clean up requirements
  11.0.0.0b3
  * Disable v3 API by default
  * Add image signing verification
  * Updated from global requirements
  * Use min and max on IntOpt option types
  * Remove WritableLogger from wsgi server
  * Port rally scenario plugin to new Rally framework
  * Use stevedore directive to document plugins
  * Catch update to a non-existent artifact property
  * Fix spelling mistake in test_images.py
  * Change URL to End User Guide
  * Fix URLs to admin-guide-cloud
  * Imported Translations from Transifex
  * Add CPU Pinning in metadata definitions
  * Fix image owner can't be changed issue in v2
  * Don't use slashes for long lines - use parentheses instead
  * Updated from global requirements
  * Imported Translations from Transifex
  * Don't import files with backed files
  * Add mechanism to limit Request ID size
  * return request_id in case of 500 error
* Thu Aug  6 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b3.dev8:
  * Updated from global requirements
  * Fix existing migrations to create utf-8 tables for MySQL DB
  * glance metadef resource-type-associate fails in postgresql
* Mon Aug  3 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b3.dev4:
  * Move to using futurist library for taskflow executors
* Sat Aug  1 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b3.dev3:
  * Imported Translations from Transifex
  * Update glance_store requirement to 0.7.1
  * Adds os_admin_user to common OS image prop metadef
* Wed Jul 29 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2:
  11.0.0.0b2
  * Updated from global requirements
  * Fix Python 3 issues in glance.tests.unit
  * Remove duplicate string
* Tue Jul 28 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2.dev65:
  * Glance to handle exceptions from glance_store
  * Keeping the configuration file with convention
* Sun Jul 26 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2.dev61:
  * Use oslo_utils.encodeutils.exception_to_unicode()
* Sat Jul 25 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2.dev59:
  * Allow ramdisk_id, kernel_id to be null on schema
* Fri Jul 24 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2.dev57:
  * Imported Translations from Transifex
  * Fix Rally job failure
  * Refactoring of image-members v2 API implementation
* Wed Jul 15 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2.dev39:
  * Healthcheck Middleware
* Tue Jul 14 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2.dev37:
  * Remove usage of assert_called_once in mocks
* Fri Jul 10 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2.dev36:
  * Rationalize test asserts
  * Updated from global requirements
* Thu Jul  9 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2.dev33:
  * Improve code readability in functional test for the WSGIServer
  * Functional of the HTTPclient was put in own method
  * Fix wrong check when create image without data
  * Remove unneeded OS_TEST_DBAPI_ADMIN_CONNECTION
  * Change default digest_algorithm value to sha256
  * Update requirements
  * Remove unused oslo incubator files
  * Remove unnecessary mixin from artifact domain model
  * Added test for "delete image member for public image"
  * VMware: vmware_ostype should be enum
* Fri Jul  3 2015 dmueller@suse.com
- add cron.hourly for running glance-scrubber
* Thu Jul  2 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2.dev17:
  * Validate size of 'min_ram' and 'min_disk'
* Wed Jul  1 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2.dev15:
  * Remove unused imported marker functions
  * Fix duplicate unique constraint in sqlite migration
* Tue Jun 30 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2.dev11:
  * Fix broken URL to docs.openstack.org
  * Switch from MySQL-python to PyMySQL
* Sat Jun 27 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2.dev8:
  * Remove unnecessary executable permission
* Fri Jun 26 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2.dev6:
  * Change generic NotFound to ImageNotFound exception
* Thu Jun 25 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2.dev5:
  * Imported Translations from Transifex
  * Add an API call to discover the list of available artifact types
  * Provide extra parameter for FakeDB
* Wed Jun 24 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0b2.dev1:
  * Fix OSProfiler exception when is enabled
  11.0.0.0b1
  * Switch to oslo.service
  * Correct text in error response
* Tue Jun 23 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0a1.dev11:
  * tests: don't hardcode strace usage
  * Fix tox -e py34
* Sun Jun 21 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0a1.dev7:
  * Drop use of 'oslo' namespace package
  * Fix Server.start() on Python 3.4
* Sat Jun 20 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0a1.dev4:
  * Imported Translations from Transifex
  * Typo fix
* Fri Jun 19 2015 cloud-devel@suse.de
- Update to version glance-11.0.0.0a1.dev1:
  * Update version for Liberty
  11.0.0a0
  * Add client_socket_timeout option
* Thu Jun 18 2015 cloud-devel@suse.de
- Update to version glance-2015.2.0.dev91:
  * Fix grammar in installation documentation
* Wed Jun 17 2015 cloud-devel@suse.de
- Update to version glance-2015.2.0.dev90:
  * Use ConfigFixture to ensure config settings are reverted
  * Change status code from 500 to 400 for image update request
* Tue Jun 16 2015 cloud-devel@suse.de
- Update to version glance-2015.2.0.dev87:
  * Pass environment variables of proxy to tox
  * Add info how to avoid issues with token expiration
  * Fix Python 3 issues
* Mon Jun 15 2015 cloud-devel@suse.de
- Update to version glance-2015.2.0.dev81:
  * Cleanup TODO in glance/gateway.py for elasticsearch being unavailable
  * Fix DbError when image params are out of range
  * REST API layer for Artifact Repository
  * Remove duplicate creation of use_user_token
  * Correct bad documentation merge
  * Sync with latest oslo-incubator
  * Fix HTTP 500 on NotAuthenticated in registry (v2)
  * Domain layer for Artifact Repository
  * Refactoring registry tests for v2
  * Return empty str for permissive, none, properties
  * Fix typo in the code
  * Fixed error message for negative values of min_disk and min_ram
  * Changes in rally-jobs/README.rst
  * Make create task as non-blocking
  * Mark task as failed in case of flow failure
  * Add VMDK as a conversion format to convert flow
  * Make properties roles check case-insensitive
  * Remove is_public from domain layer
  * Leverage dict comprehension in PEP-0274
  * Use six.moves to fix imports on Python 3
  * Imported Translations from Transifex
  * Bug : tox -egenconfig failure (no glance-search.conf)
  * Replace types.NameType with name
  * rpc: clean JSON serializer, remove strtime() usage
  * Fixed glance.tests.unit.test_artifacts_plugin_loader unit-test
  * Fix delayed activation without disk and containers formats
  * Remove string formatting from policy logging
* Thu May 28 2015 cloud-devel@suse.de
- Update to version glance-2015.2.0.dev29:
  * Register oslo.log's config options in tests
* Wed May 27 2015 cloud-devel@suse.de
- Update to version glance-2015.2.0.dev27:
  * Fix logging task id when task fails
  * Taskflow engine mode should be parallel in sample conf
* Tue May 26 2015 cloud-devel@suse.de
- Update to version glance-2015.2.0.dev23:
  * Imported Translations from Transifex
  * VMware: add VirtualVmxnet3 to hw_vif_model
* Wed May 20 2015 cloud-devel@suse.de
- Update to version glance-2015.2.0.dev20:
  * Fix test_opts to not resolve requirements
* Sat May 16 2015 cloud-devel@suse.de
- Update to version glance-2015.2.0.dev19:
  * Fix typo in documentation
  * rpc: remove wrong default value in allowed exceptions
* Fri May 15 2015 cloud-devel@suse.de
- Update to version glance-2015.2.0.dev15:
  * Set filesystem_store_datadir in tests
  * Save image data after setting the data
  * Make sure the converted image is imported
  * Updated from global requirements
  * Imported Translations from Transifex
  * Remove unneeded setup hook from setup.cfg
  * Drop use of 'oslo' namespace package
  2015.1.0
  * Metadef JSON files need to be updated
  * Plugin types are not exposed to the client
  * v1 API should be in SUPPORTED status
  * Read tag name instead of ID
  * v1 API should be in SUPPORTED status
  * API calls to Registry now maintain Request IDs
  * Updated from global requirements
  * Remove ordereddict from requirements
  * Release Import of Translations from Transifex
  * Glance database architecture section
  * update .gitreview for stable/kilo
  * Plugin types are not exposed to the client
  * Revert "Reduce DB calls when getting an image"
  * Read tag name instead of ID
  * Metadef JSON files need to be updated
  * Fix wrong docstring by copy-paste
  * Add logging when policies forbid an action
* Fri May  1 2015 cloud-devel@suse.de
- Update to version glance-2015.2.0.dev9:
  * Remove unneeded setup hook from setup.cfg
  * Drop use of 'oslo' namespace package
  2015.1.0
  * Metadef JSON files need to be updated
  * Plugin types are not exposed to the client
  * v1 API should be in SUPPORTED status
  * Read tag name instead of ID
  * API calls to Registry now maintain Request IDs
  * Updated from global requirements
  * Release Import of Translations from Transifex
  * update .gitreview for stable/kilo
  * Add logging when policies forbid an action
* Tue Apr 28 2015 cloud-devel@suse.de
- Update to version glance-2015.2.dev28:
  * v1 API should be in SUPPORTED status
  * Remove ordereddict from requirements
  * Glance database architecture section
  * Plugin types are not exposed to the client
  * Revert "Reduce DB calls when getting an image"
  * Read tag name instead of ID
  * Metadef JSON files need to be updated
  * Fix wrong docstring by copy-paste
  * Remove non-ascii characters in glance/doc/source/architecture.rst
  * Fix typos in glance/doc/source/configuring.rst
  2015.1.0rc1
  * Fixes glance-manage exporting meta definitions issue
  * Catch UnknownScheme exception
  * Refactor API function test class
  * Move elasticsearch dep to test-requirements.txt
  * Update openstack-common reference in openstack/common/README
  * glance-manage output when ran without any arguments
  * Reduce DB calls when getting an image
  * Open Liberty development
  * Zero downtime config reload (glance-control)
  * Imported Translations from Transifex
  * Glance cache to not prune newly cached images
  * glance-manage db load_metadefs does not load all resource_type_associations
  * Fix intermittent unit test failures
  * Fix intermittent test case failure due to dict order
* Mon Apr 27 2015 tbechtold@suse.com
- Adjust Requires and BuildRequires
* Thu Apr 16 2015 cloud-devel@suse.de
- Update to version glance-2015.2.dev14:
  * Revert "Reduce DB calls when getting an image"
  * Fix wrong docstring by copy-paste
  * Remove non-ascii characters in glance/doc/source/architecture.rst
  * Fix typos in glance/doc/source/configuring.rst
  2015.1.0rc1
  * Fixes glance-manage exporting meta definitions issue
  * Catch UnknownScheme exception
  * Refactor API function test class
  * Move elasticsearch dep to test-requirements.txt
  * Update openstack-common reference in openstack/common/README
  * glance-manage output when ran without any arguments
  * Reduce DB calls when getting an image
  * Open Liberty development
  * Zero downtime config reload (glance-control)
  * Imported Translations from Transifex
  * Glance cache to not prune newly cached images
  * glance-manage db load_metadefs does not load all resource_type_associations
  * Fix intermittent unit test failures
  * Fix intermittent test case failure due to dict order
  * Imported Translations from Transifex
  * A mixin for jsonpatch requests validation
  * Artifact Plugins Loader
  * Declarative definitions of Artifact Types
  * Creating metadef object without any properties
  * Zero downtime config reload (log handling)
* Thu Apr  9 2015 cloud-devel@suse.de
- Update to version glance-2015.1.dev57:
  * Fixes glance-manage exporting meta definitions issue
  * Catch UnknownScheme exception
  * Refactor API function test class
  * Creating metadef object without any properties
* Wed Apr  8 2015 cloud-devel@suse.de
- Update to version glance-2015.1.dev49:
  * Move elasticsearch dep to test-requirements.txt
  * Update openstack-common reference in openstack/common/README
* Tue Apr  7 2015 cloud-devel@suse.de
- Update to version glance-2015.1.dev46:
  * Zero downtime config reload (glance-control)
  * Imported Translations from Transifex
  * Glance cache to not prune newly cached images
  * glance-manage db load_metadefs does not load all resource_type_associations
  * Fix intermittent unit test failures
  * Fix intermittent test case failure due to dict order
  * Imported Translations from Transifex
  * A mixin for jsonpatch requests validation
  * Artifact Plugins Loader
  * Declarative definitions of Artifact Types
  * Zero downtime config reload (log handling)
  * Database layer for Artifact Repository
  * Catalog Index Service - Index Update
  * Catalog Index Service
  * Zero downtime config reload (socket handling)
  * Typo in pylintrc file
  * Fix metadef tags migrations
  * Update documentation for glance-manage
  * Fix common misspellings
  2015.1.0b3
  * Replace assert statements with proper control-flow
  * Remove use of contextlib.nested
  * Use graduated oslo.policy
  * oslo: migrate namespace-less import paths
  * Fix typo in rpc controller
* Tue Mar 31 2015 cloud-devel@suse.de
- Update to version glance-2015.1.dev26:
  * Imported Translations from Transifex
  * Catalog Index Service - Index Update
* Tue Mar 31 2015 rsalevsky@suse.com
- Update to version glance-2015.1.dev22:
  * Catalog Index Service
* Mon Mar 30 2015 cloud-devel@suse.de
- Update to version glance-2015.1.dev20:
  * Make sure the parameter has the consistent meaning
* Sun Mar 29 2015 cloud-devel@suse.de
- Update to version glance-2015.1.dev18:
  * Zero downtime config reload (log handling)
  * Database layer for Artifact Repository
  * Zero downtime config reload (socket handling)
* Fri Mar 27 2015 cloud-devel@suse.de
- Update to version glance-2015.1.dev13:
  * Typo in pylintrc file
  * Update documentation for glance-manage
  * Remove use of contextlib.nested
  * Fix typo in rpc controller
* Thu Mar 26 2015 cloud-devel@suse.de
- Update to version glance-2015.1.dev5:
  * Fix metadef tags migrations
  2015.1.0b3
  * Replace assert statements with proper control-flow
  * Use graduated oslo.policy
  * oslo: migrate namespace-less import paths
  * Fixes typo in doc-string
  * wsgi: clean JSON serializer
  * use is_valid_port from oslo.utils
  * Add ability to deactivate an image
  * Remove deprecated option db_enforce_mysql_charset
  * Raise exception if store location URL not found
  * Fix missing translations for error and info
  * Basic support for image conversion
  * Extend images api v2 with new sorting syntax
  * Add the ability to specify the sort dir for each key
  * Move to graduated oslo.log module
  * Provide a way to upgrade metadata definitions
  * Pass a real image target to the policy enforcer
  * Glance basic architecture section
  * Fix typo in configuration file
  * Updated from global requirements
  * Add sync check for models_metadef
  * Notifications for metadefinition resources
  * Update config and docs for multiple datastores support
  * Avoid usability regression when generating config
  * Glance Image Introspection
  * Add capabilities to storage driver
* Wed Mar 25 2015 cloud-devel@suse.de
- Update to version glance-2015.1.dev1:
  import migrate
  from sqlalchemy import inspect
  from sqlalchemy import (Table, Index, UniqueConstraint)
  from sqlalchemy.schema import (AddConstraint, DropConstraint)
    inspector = inspect(migrate_engine)
    metadef_namespaces = Table('metadef_namespaces', meta, autoload=True)
    metadef_properties = Table('metadef_properties', meta, autoload=True)
    metadef_objects = Table('metadef_objects', meta, autoload=True)
    metadef_ns_res_types = Table('metadef_namespace_resource_types',
    meta, autoload=True)
    metadef_resource_types = Table('metadef_resource_types', meta,
    autoload=True)
    metadef_tags = Table('metadef_tags', meta, autoload=True)
    Index('ix_namespaces_namespace', metadef_namespaces.c.namespace).drop()
    Index('ix_objects_namespace_id_name', metadef_objects.c.namespace_id,
    metadef_objects.c.name).drop()
    Index('ix_metadef_properties_namespace_id_name',
    metadef_properties.c.namespace_id,
    metadef_properties.c.name).drop()
    fkc = migrate.ForeignKeyConstraint([metadef_tags.c.namespace_id],
    [metadef_namespaces.c.id])
    fkc.create()
    [#] `migrate` module removes unique constraint after adding
    [#] foreign key to the table in sqlite.
    [#] The reason of this issue is that it isn't possible to add fkc to
* Sat Feb 28 2015 cloud-devel@suse.de
- Update to version glance-2015.1.dev40:
  * Remove en_US translation
  * Synchronising oslo-incubator service module
  * Updated from global requirements
  * Glance returns HTTP 500 for image download
  * Remove boto from requirements.txt
  * Unbreak python-swiftclient gate
  * Imported Translations from Transifex
  * Removes unnecessary assert
  * Prevents swap files from being found by Git
  * Add BadStoreConfiguration handling to glance-api
  * Remove redundant parentheses in conditional statements
  * Image data remains in backend for deleted image
  * unify some messages
  * Clarified doc of public_endpoint config option
  * Add detail description of image_cache_max_size
  * Updated from global requirements
  2015.1.0b2
  * Add Support for TaskFlow Executor
  * Fix for CooperativeReader to process read length
  * Software Metadata Definitions
  * Updated from global requirements
  * Rewrite SSL tests
  * Replace snet config with endpoint config
  * Simplify context by using oslo.context
  * Handle empty request body with chunked encoding
* Wed Feb 18 2015 cloud-devel@suse.de
- Update to version glance-2015.1.dev17:
  * Image data remains in backend for deleted image
  * Clarified doc of public_endpoint config option
  * Add detail description of image_cache_max_size
  * Updated from global requirements
  2015.1.0b2
  * Add Support for TaskFlow Executor
  * Fix for CooperativeReader to process read length
  * Software Metadata Definitions
  * Updated from global requirements
  * Rewrite SSL tests
  * Replace snet config with endpoint config
  * Simplify context by using oslo.context
  * Update vmware_adaptertype metadef values
  * Typos fixed in the comments
  * Updated from global requirements
  * Redundant __init__ def in api.authorization.MetadefTagProxy
  * Make digest algorithm configurable
  * Switch to mox3
  * Remove argparse from requirement
  * Remove optparse from glance-replicator
  * Eliminate shell param from subprocesses in tests
  * Remove test dependency on curl
  * Cleanup chunks for deleted image that was 'saving'
  * remove need for netaddr
  * Fix copy-from when user_storage_quota is enabled
* Fri Feb 13 2015 dmueller@suse.com
- update logrotate.conf
* Wed Feb  4 2015 cloud-devel@suse.de
- Update to version glance-2015.1.dev87:
  * Replace snet config with endpoint config
  * Simplify context by using oslo.context
  * Update vmware_adaptertype metadef values
  * Typos fixed in the comments
  * Updated from global requirements
  * Redundant __init__ def in api.authorization.MetadefTagProxy
  * Make digest algorithm configurable
  * Switch to mox3
  * Remove optparse from glance-replicator
  * Remove test dependency on curl
  * Cleanup chunks for deleted image that was 'saving'
  * remove need for netaddr
  * Fix copy-from when user_storage_quota is enabled
  * remove extraneous --concurrency line in tox
  * SQL scripts should not manage transactions
  * Fixes line continuations
  * Upgrade to hacking 0.10
  * Removed python-cinderclient from requirements.txt
  * Move from oslo.db to oslo_db
  * Move from oslo.config to oslo_config
  * Improve documentation for glance_stores
  * Fix reference to "stores" from deprecated name
  * Move from oslo.utils to oslo_utils
  * Updated from global requirements
  * Updated from global requirements
  * Prevent file, swift+config and filesystem schemes
  * Simplify usage of str.startswith
  * Adding filesystem schema check in async task
* Mon Feb  2 2015 cloud-devel@suse.de
- Update to version glance-2015.1.dev78:
  * Updated from global requirements
  * Redundant __init__ def in api.authorization.MetadefTagProxy
  * Make digest algorithm configurable
  * Switch to mox3
  * Remove optparse from glance-replicator
  * Remove test dependency on curl
  * Cleanup chunks for deleted image that was 'saving'
  * remove need for netaddr
  * remove extraneous --concurrency line in tox
  * SQL scripts should not manage transactions
  * Fixes line continuations
  * Upgrade to hacking 0.10
  * Removed python-cinderclient from requirements.txt
  * Move from oslo.db to oslo_db
  * Move from oslo.config to oslo_config
  * Improve documentation for glance_stores
  * Fix reference to "stores" from deprecated name
  * Move from oslo.utils to oslo_utils
  * Updated from global requirements
  * Updated from global requirements
  * Prevent file, swift+config and filesystem schemes
  * Simplify usage of str.startswith
  * Adding filesystem schema check in async task
  * Fix spelling typo
  * Fix rendering of readme document
  * Imported Translations from Transifex
  * Fix document issue of image recover status
  * rename oslo.concurrency to oslo_concurrency
* Wed Jan 14 2015 tbechtold@suse.com
- Update to version glance-2015.1.dev44:
  * Move from oslo.utils to oslo_utils
  * Updated from global requirements
  * Updated from global requirements
  * Prevent file, swift+config and filesystem schemes
    to avoid unrestricted path traversal (bnc#913645, CVE-2015-1195)
  * Simplify usage of str.startswith
  * Fix spelling typo
  * Fix rendering of readme document
  * Imported Translations from Transifex
  * Fix document issue of image recover status
  * rename oslo.concurrency to oslo_concurrency
  * Provide a quick way to run flake8
  * Fix 3 intermittently failing tests
  * Removed obsolete db_auto_create configuration option
  * Fix client side i18n support for v1 api
  * Move default_store option in glance-api.conf
  * Remove _i18n from openstack-common
  * Adds the ability to sort images with multiple keys
  * Add sort key validation in v2 api
  * Fixes typo: glance exception additional dot
  * Allow $OS_AUTH_URL environment variable to override config file value
  * Bump API version to 2.3
  * Replace '_' with '_LI', '_LE', '_LW', '_LC'
  2015.1.0b1
  * Generate glance-manage.conf
  * Imported Translations from Transifex
- Adjust Requires according to requirements.txt
- Install glance-manage.conf
* Wed Jan 14 2015 tbechtold@suse.com
- Update to version glance-2015.1.dev44:
  * Move from oslo.utils to oslo_utils
  * Updated from global requirements
  * Updated from global requirements
  * Prevent file, swift+config and filesystem schemes
  * Simplify usage of str.startswith
  * Fix spelling typo
  * Fix rendering of readme document
  * Imported Translations from Transifex
  * Fix document issue of image recover status
  * rename oslo.concurrency to oslo_concurrency
  * Provide a quick way to run flake8
  * Fix 3 intermittently failing tests
  * Removed obsolete db_auto_create configuration option
  * Fix client side i18n support for v1 api
  * Move default_store option in glance-api.conf
  * Remove _i18n from openstack-common
  * Adds the ability to sort images with multiple keys
  * Add sort key validation in v2 api
  * Fixes typo: glance exception additional dot
  * Allow $OS_AUTH_URL environment variable to override config file value
  * Bump API version to 2.3
  * Replace '_' with '_LI', '_LE', '_LW', '_LC'
  2015.1.0b1
  * Generate glance-manage.conf
  * Imported Translations from Transifex
  * Adding Metadef Tag support
  * Removed unnecessary dot(.) from log message
* Thu Dec 11 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev167.gf8b6149:
  * Update glance.openstack.common.policy and cleanup
* Wed Dec 10 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev165.ga64639e:
  * Fix typo in common module
* Tue Dec  9 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev163.g9447d37:
  * Fix and add a test case for IPv6
* Sun Dec  7 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev162.g12f12fb:
  * Fix getaddrinfo if dnspython is installed
* Fri Dec  5 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev160.g038cf54:
  * Allow None values to be returned from the API
* Wed Dec  3 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev158.g219abd7:
  * Expose nullable fields properties
  * Allow some fields to be None
  * A small refactoring of the domain
  * No 4 byte unicode allowed in image parameters
  * Update rally-jobs files
* Wed Dec  3 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev148.gf8d8120:
  * Correct GlanceStoreException to provide valid message - Glance
* Sat Nov 29 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev146.gf82574f:
  * Updated from global requirements
  * Disable osprofiler by default
* Thu Nov 27 2014 dmueller@suse.com
- Update to version glance-2015.1.dev143.g067b0db:
  * Remove Python 2.6 classifier
  * Move from using _ builtin to using glance.i18n _
  * Change Glance to use i18n instead of gettextutils
  * Raising glance logging levels
  * Imported Translations from Transifex
  * Do not use LazyPluggable
  * metadef modules should only use - from wsme.rest import json
  * Wrong order of assertEquals args(Glance)
  * Removal of unnecessary sample file from repository
  * Typo correction of the prefix value in compute-host-capabilities
  * vim ropeproject directories added to gitignore
  * Update the vmware_disktype metadefs values
  * Separate glance and eventlet wsgi logging
  * Handle some exceptions of image_create v2 api
  * Isolate test from environment variables
* Sat Nov 15 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev114.g9622189:
  * Remove openstack.common.test
* Fri Nov 14 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev112.g16ab93d:
  * Use unicode for error message
* Wed Nov 12 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev110.gfe93940:
  * Upgrade tests' mocks to match glance_store
  * Remove exception declarations from replicator.py
* Tue Nov 11 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev107.gfed99f9:
  * Replace custom lazy loading by stevedore
  * Make RequestContext use auth_token (not auth_tok)
* Thu Nov  6 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev103.gcf62047:
  * Ignore Eric IDE files and folders in git
* Tue Nov  4 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev101.gc5d6cad:
  * Raise an exception when quota config parameter is broken
* Sat Nov  1 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev99.gb289e40:
  * Initiate deletion of image files if the import was interrupted
    to prevent denial of service (bnc#918784, CVE-2014-9684)
  * Fix context storage bug
  * Swift Multi-tenant store: Pass context on upload
* Thu Oct 30 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev93.g392ee80:
  2014.2
  * Fix options and their groups - etc/glance-api.conf
  * Adjust authentication.rst doc to reference "identity_uri"
  2014.2.rc2
  * Use identity_uri instead of older fragments
  * Prevent setting swift+config locations
  * Metadef schema column name is a reserved word in MySQL
  * Remove stale chunks when failed to update image to registry
  * GET property which name includes resource type prefix
  * g-api raises 500 error while uploading image
  * Fix for Adopt glance.store library in Glance
  * Update Metadefs associated with ImagePropertiesFilter
  * updated translations
  * Use ID for namespace generated by DB
  * Metadef Property and Object schema columns should use JSONEncodedDict
  * Add missing metadefs for shutdown behavior
  * Update driver metadata definitions to Juno
  * Mark custom properties in image schema as non-base
  * Specify the MetadefNamespace.namespace column is not nullable
  * Make compute-trust.json compatible with TrustFilter
  * Include Metadata Defs Concepts in Dev Docs
  * Nova instance config drive Metadata Definition
  * Add missing metadefs for Aggregate Filters
  * Updated from global requirements
* Mon Oct 27 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev91.gded0852:
  * change default value for s3_store_host
  * remove url-path from the default value of s3_store_host
  * Complete the change of adding public_endpoint option
  * Add config option to override url for versions
  * Remove modules from openstack-common.conf
  * Improve error log for expired image location url
  * Remove eventlet_hub option
  * Glance scrubber should page thru images from registry
  * Add logging to image_members and image_tags
  * Can not delete images if db deadlock occurs
  * Refactor metadef ORM classes to use to_dict instead of as_dict
* Fri Oct 17 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev74.gd4f8907:
  * Update glance.openstack.common
* Wed Oct 15 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev73.gc4e19b8:
  * Reduce extraneous test output
* Wed Oct 15 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev71.gae7aeed:
  * Fix options and their groups - etc/glance-api.conf
* Wed Oct 15 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev69.g46a6f0e:
  * Fix for adopt glance.store library in Glance
  * Adjust authentication.rst doc to reference "identity_uri"
  * Stop using intersphinx
* Sat Oct 11 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev64.g2365a3f:
  * Fix assertEqual arguments order
* Fri Oct 10 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev63.ge33667e:
  * Prevent setting swift+config locations
  * Remove stale chunks when failed to update image to registry
  * Use specific exceptions instead of the general MetadefRecordNotFound
  * Metadef schema column name is a reserved word in MySQL
  * Update Metadefs associated with ImagePropertiesFilter
* Thu Oct  9 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev54.g27c179f:
  * Fix for Adopt glance.store library in Glance
  * GET property which name includes resource type prefix
  * Incorrect parameters passed
  * g-api raises 500 error while uploading image
  * Minor style tidy up in metadata code
  * Metadef Property and Object schema columns should use JSONEncodedDict
  * Updated from global requirements
  * Use ID for namespace generated by DB
  * Add missing metadefs for shutdown behavior
  * Fix missing space in user_storage_quota help message
* Wed Oct  8 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev35.gbcaea50:
  * Switch to oslo.serialization
  * Switch to oslo.utils
  * Imported Translations from Transifex
  * hacking: upgrade to 0.9.x serie
  * Update driver metadata definitions to Juno
  * Specify the MetadefNamespace.namespace column is not nullable
  * Add missing metadefs for Aggregate Filters
  * Nova instance config drive Metadata Definition
* Tue Oct  7 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev21.g353ae24:
  * Run tests with default concurrency 0
  * Refactor test_migrations module
* Sat Oct  4 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev17.g6266a44:
  * Include Metadata Defs Concepts in Dev Docs
* Fri Oct  3 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev15.gc1188da:
  * Fix bad header bug in glance-replicator
  * Mark custom properties in image schema as non-base
  * Fix glance V2 incorrectly implements JSON Patch'add'
  * Make compute-trust.json compatible with TrustFilter
* Wed Oct  1 2014 cloud-devel@suse.de
- Update to version glance-2015.1.dev7.g116c1de:
  * Open Kilo development
  2014.2.rc1
  * replace dict.iteritems() with six.iteritems(dict)
  * Fixes logging in image_import's main module
  * ignore .idea folder in glance
  * Use identity_uri instead of older fragments
* Mon Sep 29 2014 tbechtold@suse.com
- Update to version glance-2014.2.dev47.gd659161:
  * Imported Translations from Transifex
  * Add documentation for a new storage file permissions option
  * Remove db_enforce_mysql_charset option for db_sync of glance-manage
  * replace dict.iteritems(
- Don't install oslo-config-generator files
* Thu Sep 25 2014 tbechtold@suse.com
- Update to version glance-2014.2.dev42.gb46784e:
  * Add specific docs build option to tox
  * Updated from global requirements
  * replace dict.iteritems() with six.iteritems(dict)
  * Enforce using six.text_type() over unicode()
  * Fixes Error Calling GET on V1 Registry
  * Enabling separated sample config file generation
  * Replaces assertEqual with assertTrue and assertFalse
  * Sync glance docs with metadefs api changes
  * Change open(file) to with block
  * Duplicated image id return 409 instead of 500 in API v2
  * Glance API V2 can't recognize parameter 'id'
* Fri Sep 19 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev22.g1cdc555:
  * replace dict.iteritems(
  * Remove uses of unicode() builtin
* Thu Sep 18 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev21.gb31d7a4:
  * Remove uses of unicode(
* Wed Sep 17 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev20.gb68c647:
  * Just call register_opts in tests
* Mon Sep 15 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev18.g7374d93:
  * Improve OS::Compute::HostCapabilities description
* Sun Sep 14 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev16.g6513c58:
  * Block sqlalchemy-migrate 0.9.2
  * Adds missing db registry api tests for Tasks
* Fri Sep 12 2014 dmueller@suse.com
- Update to version glance-2014.2.dev13.ge550cac:
  * Fix CommonImageProperties missing ":"
  * Fix VMware Namespace capitalization & description
  * Imported Translations from Transifex
  * API support for random access to images
  * Adopt glance.store library in Glance
  * warn against sorting requirements
  * Introduces eventlet executor for Glance Tasks
  * Glance Metadata Definitions Catalog - Seed
* Tue Sep  2 2014 dmueller@suse.com
- fix requires
* Mon Sep  1 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev67.g2e7de07:
  * Glance Metadata Definitions Catalog - API
* Sun Aug 31 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev66.gb9107a7:
  * Glance Metadata Definitions Catalog - DB
  * Restrict users from downloading protected image
* Sat Aug 30 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev62.g34904da:
  * Syncing changes from oslo-incubator policy engine
* Wed Aug 27 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev60.g640dd1e:
  * Fix legacy tests using system policy.json file
  * Improve Glance profiling
  * Changes HTTP response code for unsupported methods
  * Improved coverage for glance.api.*
* Tue Aug 26 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev52.g65c4e73:
  * Fix collection order issues and unit test failures
  * Replacement mox by mock
* Mon Aug 25 2014 bwiedemann@suse.com
- use %%_rundir if available, otherwise /var/run
* Thu Aug 21 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev49.gf4af05d:
  * Check on schemes not stores
  * Imported Translations from Transifex
  * Bump osprofiler requirement to 0.3.0
* Wed Aug 20 2014 tbechtold@suse.com
- Update to version glance-2014.2.dev43.g7c89cdb:
  * Log task ID when the task status changes
  * Catch exception.InUseByStore at API layer
- Add python-posix_ipc and python-osprofiler to Requires
  according to requirements.txt
* Wed Aug 20 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev40.g01ced52:
  * Enforce image_size_cap on v2 upload (bnc#892779, CVE-2014-5356)
  * Ensure constant order when setting all image tags
* Mon Aug 18 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev36.g0e2bc1d:
  * Do not assume order of images
  * Fix migration on older postgres
* Thu Aug 14 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev32.g653efdd:
  * Fix bad indentation in glance
* Wed Aug 13 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev30.g8c31eb5:
  * Use @mock.patch.object instead of mock.MagicMock
  * Adding status field to image location -- scrubber queue switching
* Tue Aug 12 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev26.g3bd4840:
  * Fix image killed after deletion
* Mon Aug 11 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev24.g941a81d:
  * Fix rally performance job in glance
  * Integrate OSprofiler and Glance
  * VMware store: Use the Content-Length if available
  * Fix RBD store to use READ_CHUNKSIZE
  * Quota column name 'key' in downgrade script
  * Enable F821 check: undefined name 'name'
  * Adding status field to image location -- scrubber changes
* Sun Aug  3 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev13.gfdcdd6e:
  * Trivial fix typo: Unavilable to Unavailable
  * Do not log password in swift URLs in g-registry
* Sat Aug  2 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev9.g63600d1:
  * Fixes the failure of updating or deleting image empty property
* Fri Aug  1 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev7.gca4e2a1:
  * Use `_LW` where appropriate in db/sqla/api
  * Moving eventlet.hubs.use_hub call up
* Thu Jul 31 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev3.gf41b305:
  * Updated from global requirements
* Wed Jul 30 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev2.gff3161a:
  * Log upload failed exception trace rather than debug
* Thu Jul 24 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev1.g5148c96:
  * Decouple read chunk size from write chunk size
  2014.2.b2
* Tue Jul 22 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev107.g323aba6:
  * Security hardening: fix possible shell injection vulnerability
  * Move to oslo.db
  * Also run v2 functional tests with registry
* Mon Jul 21 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev101.gcf64acf:
  * Set defaults for amqp in glance-registry.conf
* Sat Jul 19 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev99.g44e607d:
  * Refactoring Glance logging lowering levels
  * Raising 400 Bad Request when using "changes-since" filter on v2
* Thu Jul 17 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev95.g36818b4:
  * Fix typo in swift store message
  * Add a `_retry_on_deadlock` decorator
  * Use auth_token from keystonemiddleware
  * Allow some property operations when quota exceeded
  * Switch over oslo.i18n
* Wed Jul 16 2014 vuntz@suse.com
- Call "glance-manage db sync" instead of glance-manage db_sync" in
  init script since it's the new way upstream.
* Sat Jul 12 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev87.gde6be83:
  * Adding status field to image location -- domain and APIs changes
  * Pass Message object to webob exception
* Fri Jul 11 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev83.g7ce4460:
  * Changing replicator to use openstack.common.log
  * Fix unsaved exception in v1 API controller
  * Some exceptions raise UnicodeError
* Thu Jul 10 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev77.g61732b1:
  * Add task functions to v2 registry
  * Handle session timeout in the VMware store
  * Some v2 exceptions raise unicodeError
  * Resolving the performance issue for image listing of v2 API on server
* Wed Jul  9 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev69.g4829dee:
  * Fix docstrings in enforce() and check() policy methods
  * Changing Sheepdog driver to use correct configuration function
* Tue Jul  8 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev65.g424eb6d:
  * Fix typo in comment
  * Updated from global requirements
  * Added an extra parameter to the df command
  * Update documentation surrounding the api and registry servers
  * Remove unused methods
* Mon Jul  7 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev56.g949e94c:
  * Imported Translations from Transifex
  * Updated from global requirements
  * Fix unsaved exception in store.rbd.Store.add()
* Fri Jul  4 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev51.g3419ecc:
  * Raise NotImplementedError instead of NotImplemented
  * Use (# of CPUs) glance workers by default
* Tue Jul  1 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev48.g8c1a2d9:
  * Add CONTRIBUTING.rst
  * Imported Translations from Transifex
  * Fix swift functional test
* Mon Jun 30 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev42.gdde2cba:
  * Sync processutils and lockutils from oslo with deps
* Sat Jun 28 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev41.gb7968cf:
  * Document registry 'workers' option
* Fri Jun 27 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev40.gdb2a567:
  * Removing translation from debug messages
  * Unifies how BadStoreUri gets raised and logged
  * Fix lazy translation UnicodeErrors
  * Synced jsonutils and its dependencies from oslo-incubator
* Thu Jun 26 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev34.g075b7db:
  * Implemented S3 multi-part upload functionality
* Wed Jun 25 2014 dmueller@suse.com
- Update to version glance-2014.2.dev32.gbe6e487:
  * Log swift container creation
  * Remove user and key from location in swift
  * Add pluging sample for glance gate
* Fri Jun 20 2014 dmueller@suse.com
- package log/glance as 0750
* Fri Jun 20 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev27.geeefdf7:
  * Updated from global requirements
  * Changed psutil dep. to match global requirements
  * Fixes v2 return status on unauthorized download
  * notifier: remove notifier_strategy compat support
  * colorizer: use staticmethod rather than classmethod
  * Assign local variable in api.v2.image_data
  * Use df(1) in a portable way
* Thu Jun 19 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev13.gca6eb80:
  * Do not call configure several times at startup
  * notifier: simply notifier_strategy compat support
* Wed Jun 18 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev10.gc6dd491:
  * Move `location`'s domain code out of glance.store
  * sync oslo incubator code
  * Bump python-swiftclient version
  * To fixes import error for run_tests.sh
* Sun Jun 15 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev2.g00bc84b:
  2014.2.b1
  * Remove duplicated is_uuid_like() function
* Tue Jun 10 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev96.g9c87169:
  * Add test for no_translate_debug_logs hacking check
  * Add hacking checks
  * replace dict.iteritems() with six.iteritems(dict)
  * make uploading an image as public admin only by default
* Thu Jun  5 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev88.g1069159:
  * remove default=None for config options
* Thu May 29 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev87.g5f04cce:
  * Use Chunked transfer encoding in the VMware store
* Tue May 27 2014 dmueller@suse.com
- update setting to non-deprecated value for notification strategy
* Tue May 27 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev85.g0b1d28a:
  * TaskTest:test_fail() should use asserIstNone
  * debug level logs should not be translated
  * use /usr/bin/env python instead of /usr/bin/python
  * fixed typos found by RETF rules in RST files
  * Removing duplicate entry from base_conf
  * Fixes spelling error in test name
* Sun May 25 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev73.g371533b:
  * Remove all mostly untranslated PO files
* Thu May 22 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev72.gedc4856:
  * Clean up openstack-common.conf
* Wed May 21 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev70.gf7effe4:
  * Use safe way through "with" statement to work with files
  * Fix various Pep8 1.5.4 errors
* Tue May 20 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev66.ge4c7c57:
  * Fixed a handful of typos
* Thu May 15 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev64.gaed6b8f:
  * Use safe way through "with" statement to work with files
  * Add rally performance gate job for glance
* Fri May  9 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev61.g3e48e35:
  * Replace unicode() for six.text_type
* Thu May  8 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev59.gfcfb5d0:
  * Ensures that task.message is of type unicode
* Wed May  7 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev58.g503be24:
  * Prevent creation of http images with invalid URIs
* Sat May  3 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev57.ged816a2:
  * Fixes installation of test-requirements
* Tue Apr 29 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev56.g7cffaac:
  * Fixes "bad format" in replicator for valid hosts
* Tue Apr 22 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev54.g001dd01:
  * Uses None instead of mutables for function param defaults
* Mon Apr 21 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev52.g8c39691:
  * Configuration doc for VMware storage backend
  * Enable H304 check
  * VMware Datastore storage backend
* Sun Apr 20 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev39.ga582b55:
  * Sync latest network_utils module from Oslo
* Fri Apr 18 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev37.g3db3b67:
  * Replace assert* with more suitable asserts in unit tests
  * Get rid of TaskDetails in favor of TaskStub
  * Provide explicit image create value for test_image_paginate case
* Wed Apr 16 2014 dmueller@suse.com
- update connection string to database group
* Wed Apr 16 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev31.g2c0d214:
  * Added undescore function to some log messages
* Sat Apr 12 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev29.g182594e:
  * Fixes Glance Registry V2 client
  * Update Glance configuration sample files for database options
  * To prevent remote code injection on Sheepdog store
* Fri Apr 11 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev23.g89da136:
  * Updated from global requirements
* Wed Apr  9 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev21.g0741c40:
  * Adds TaskStub class
  * Do not allow HEAD images/detail
  * Fix deprecation warning in test_multiprocessing
* Tue Apr  8 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev15.gcff35c1:
  * user_storage_quota now accepts units with value
* Sun Apr  6 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev14.ga1b216a:
  * Catch loading failures if transport_url is not set
  * Fix Jenkins translation jobs
* Fri Apr  4 2014 cloud-devel@suse.de
- Update to version glance-2014.2.dev10.g1c90472:
  * Fixed the pydev error message
  2014.1.rc1
  * Open Juno development
  * Do not set Location header on HTTP/OK (200) responses
  * When re-raising exceptions, use save_and_reraise
  * Do not use __builtin__ in python3
* Wed Apr  2 2014 speilicke@suse.com
- Cleanup dependencies
* Wed Apr  2 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev52.g5fa3d2e:
  * Making DB sanity checking be optional for DB migration
  * Fix swift functional test "test_create_store"
* Sat Mar 29 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev49.g11b1a7f:
  * Sanitize set passed to jsonutils.dumps()
  * Sync common db code from Oslo
* Fri Mar 28 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev47.g9a31a64:
  * Sanitize set passed to jsonutils.dumps(
  * Imported Translations from Transifex
* Thu Mar 27 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev44.gdc2672a:
  * Return 405 when attempting DELETE on /tasks
  * Removes use of timeutils.set_time_override
  * Remove dependency of test_v1_api on other tests
* Wed Mar 26 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev38.gb5d3295:
  * Pass Message object to webob exception
* Tue Mar 25 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev36.gaabc62a:
  * VMware store.add to return the image size uploaded
  * registry: log errors on failure
* Sat Mar 22 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev32.g09265f6:
  * Remove openstack.common.fixture
* Fri Mar 21 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev31.g49d3220:
  * Detect MultiDict when generating json body
* Tue Mar 18 2014 dmueller@suse.com
- fix requires
* Mon Mar 17 2014 rhafer@suse.com
- switch over to non-openstack-prefix'ed users
* Mon Mar 17 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev29.gddae276:
  * Make the VMware datastore backend more robust
  * Add copyright text to glance/openstack/common/__init__.py
* Sat Mar 15 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev26.gc6365cc:
  * Makes possible to enable Registry API v1 and v2
  * Fix glance db migration failed on 031
  * Include Location header in POST /tasks response
  * Catch exception when image cache pruning
* Fri Mar 14 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev19.g2d3fa9e:
  * Updated from global requirements
  * Provide an upgrade period for enabling stores
  * API v2: Allow GET on unowned images with show_image_direct_url
* Thu Mar 13 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev14.g09b583e:
  * Remove import specific validation from tasks resource
* Wed Mar 12 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev12.gcce794f:
  * Don't enable all stores by default
  * Provide explicit image create value in Registry v2 API test
* Tue Mar 11 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev8.g78abbcb:
  2014.1.b3
  * Log 'image_id' with all BadStoreURI error messages
* Thu Mar  6 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev147.g70422c4:
  * Document for API message localization
  * Add the OVA container format
  * Store URI must start with the expected URI scheme
* Wed Mar  5 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev141.gf70b72b:
  * Add support for API message localization
* Tue Mar  4 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev140.gbfddf66:
  * Replaced calls of get(foo, None) -> get(foo)
* Mon Mar  3 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev138.g3838629:
  * Documentation for Glance tasks
  * Sync common db code from Oslo
* Sat Mar  1 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev134.g0e2b8ca:
  * VMware storage backend should use oslo.vmware
  * Refactor UUID test
  * Rename Openstack to OpenStack
  * Fix 031 migration failed on DB2
* Thu Feb 27 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev126.g0190393:
  * Use six.StringIO/BytesIO instead of StringIO.StringIO
* Wed Feb 26 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev125.g6165966:
  * Use 0-based indices for location entries
  * Keep py3.X compatibility for urllib
* Tue Feb 25 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev121.g8739451:
  * Replaced "...\'%%s\'..." with "...'%%s'..."
  * Updated from global requirements
* Sun Feb 23 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev118.g09fd5a6:
  * Fix logging context to include user_identity
  * Added undescore function to some strings
  * Replacement mox by mock
  * Add support for PartialTask list
* Fri Feb 21 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev111.g8762a7b:
  * Glance all: Replace basestring by six for python3 compatability
  * Delete image metadata after image is deleted
  * Modify assert statement when comparing with None
  * Enable hacking H301 and disable H304, H302
* Wed Feb 19 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev104.g4267af6:
  * Use uuid instead of uuidutils
  * Use six.moves.urllib.parse instead of urlparse
  * Switch over to oslosphinx
  * Fix parsing of AMQP configuration
  * Enable F841 check
  * Sync log.py from oslo
  * Improve help strings
* Wed Feb 19 2014 dmueller@suse.com
- remove 0001-Switch-over-to-oslosphinx.patch
* Fri Feb 14 2014 cloud-devel@suse.de
- Update to version glance-2014.1.dev90.ge98576e:
  * Add `virtual_size` to Glance's API v2
  * Add a virtual_size attribute to the Image model
  * Adding status field to image location -- DB migration
* Thu Feb 13 2014 dmueller@suse.com
- added patches:
  * 0001-Switch-over-to-oslosphinx.patch
* Wed Feb 12 2014 dmueller@suse.com
- fix permissions of cachedir
- fix requirements (switched to testrepository)
* Tue Feb 11 2014 speilicke@suse.com
- Update to version glance-2014.1.dev86.g70ff603:
  * Add a mailmap entry for myself
  * Add unit tests around glance-manage
  * Remove tox locale overrides
  * Apply image location selection strategy
  * Switch to testrepository for running tests
  * Clean up DatabaseMigrationError
  * Enable H302 check
  * Fix misspellings in glance
  * Expose image property 'owner' in v2 API
  * Removes logging of location uri
  * Updated from global requirements
  * Remove duplicate type defination of v2 images schema
  * Enable H202 check
  * Modify my mailmap
  * glance-manage wont take version into consideration
  * Move scrubber outside the store package
  * Depending on python-swiftclient>=1.6
  * Now psutil>=1.1.0 is actually on PyPI
  * Fix indentation errors found by Pep8 1.4.6+
  * Add VMware storage backend to location strategy
  * glance requires pyOpenSSL>=0.11
  * Imported Translations from Transifex
  * VMware Datastore storage backend
  * Restore image status to 'queued' if upload failed
  * Don't override transport_url with old configs
  * Provide explicit image create value in Registry v2 Client test
  * Provide explicit task create and update value in controller tests
- Replace git_tarballs source service with download_files and set_version
  + Use upstream URL as source (enables verification)
* Thu Feb  6 2014 dmueller@suse.com
- fix dependencies
* Thu Feb  6 2014 dmueller@suse.com
- fix typo in logrotate
* Wed Feb  5 2014 iartarisi@suse.com
- Added missing requirement: python-suds
* Sun Feb  2 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev39.g22408ff:
  + Log a warning when a create fails due to quota
* Sat Feb  1 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev37.g233ef86:
  + Add multifilesystem store to support NFS servers as backend
  + Prevent E500 when delayed delete is enabled
  + Imported Translations from Transifex
* Fri Jan 31 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev31.g84954a8:
  + Update all the glance manpages
  + VMware Datastore storage backend
  + Retry failed image download from Swift
* Thu Jan 30 2014 dmueller@suse.com
- move lock_path to /var/run
* Thu Jan 30 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev26.g64d5c97:
  + Sync with global requirements
* Wed Jan 29 2014 vuntz@suse.com
- Package /var/lock/glance, and set lock_path in config files.
- Use correct group name for directory ownerships.
- Do not make /var/run/glance readable by others.
* Wed Jan 29 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev24.gd390e85:
  + Enable hacking H703 check
* Tue Jan 28 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev22.g5ab50f4:
  + Sync oslo.messaging version with global-requirements
* Mon Jan 27 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev21.g876c53a:
  + Use common db migrations module from Oslo
  + Check --store parameter validity before _reserve
* Sun Jan 26 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev18.g446736e:
  + Sync gettextutils from Oslo
* Sat Jan 25 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev16.g23c61fd:
  + Enable gating on H501
  + Tests added for glance/cmd/cache_pruner.py
* Fri Jan 24 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev12.gdf71015:
  + Fix the incorrect log message when creating images
  + Fix inconsistent doc string and code of db_sync
  + Check image id format before executing operations
  + Sync unhandled exception logging change from Oslo
  + Restore image status on duplicate image upload
  + Adding image location selection strategies
  + fix bug:range() is not same in py3.x and py2.x
  + Check first matching rule for protected properties
* Mon Jan 20 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev163.g2c4bd69:
  + Change assertTrue(isinstance()) by optimal assert
* Sun Jan 19 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev161.gc4a57b4:
  + fixing typo in rst file
* Sat Jan 18 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev159.g016204e:
  + Fix tmp DB path calculation for test_migrations.py
  + Update the glance-api manpage
* Fri Jan 17 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev155.gbad366a:
  + Remove 'openstack/common/context.py'
  + Bump hacking to 0.8 and get python 3.x compatibility
  + add log for _get_images method
* Thu Jan 16 2014 dmueller@suse.com
- remove flake/pep8 requires, they come from hacking now
* Thu Jan 16 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev149.g9e9ce64:
  + Allow users to customize max header size
  + Makes 'expires_at' not appear if not set on task
  + Remove vim header
* Tue Jan 14 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev143.g7834f97:
  + Decouple the config dependence on glance domain
  + Adding logs to tasks
  + Cleans up imports in models.py
  + Fix typo in doc string
* Mon Jan 13 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev136.g1d35a88:
  + assertEquals is deprecated, use assertEqual (H234)
  + Switch to Hacking 0.8.x
  + Set image size to None after removing all locations
  + Prevent min_disk and min_ram from being negative
  + Update README to the valid Oslo-incubator doc
  + Skip unconfigurable drivers for store initialization
* Sun Jan 12 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev124.g340efa4:
  + Sync with oslo-incubator (git 6827012)
  + Added unit tests for api/middleware/cache_manage.py
  + Oslo sync to recover from db2 server disconnects
  + Align glance-api.conf rbd option defaults with config
  + Sync Log levels from OSLO
  + Fix call to store.safe_delete_from_backend
  + Increase test coverage for glance.common.wsgi
* Sat Jan 11 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev110.gf19bfe2:
  + Add config option to limit image locations
* Fri Jan 10 2014 dmueller@suse.com
- set default keystone signing dir
* Fri Jan 10 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev108.g8efd443:
  + Fix typo in gridfs store
  + replace type calls with isinstance
  + fix comments and docstrings misspelled words
* Thu Jan  9 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev103.g20ad8fd:
  + Consider  @,! in properties protection rule as a configuration error
* Wed Jan  8 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev101.g61a715e:
  + Remove unused imports in glance
  + Remove return stmt of add,save and remove method
  + Migrate json to glance.openstack.common.jsonutils
* Tue Jan  7 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev96.gf7a1443:
  + Enable gating on F811 (duplicate function definition)
* Sat Jan  4 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev94.g3ac094c:
  + Use common Oslo database session
  + Define sheepdog_port as an integer value
  + Set image size after updating/adding locations
* Thu Jan  2 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev89.g4e28e4d:
  + Fixed wrong string format in glance.api.v2.image_data
  + Cleanup: remove unused code from store_utils
  + Remove duplicate method implementations in ImageLocationsProxy
  + Add db2 communication error code when check the db connection
  + Correct URL in v1 test_get_images_unauthorized
  + Use uuid instead of uuidutils
  + Enable H233/H301/H302 tests that are ignored at the moment
  + Make code base E125 and E126 compliant
  + Empty files shouldn't contain copyright nor license
  + Refactor tests.unit.utils:FakeDB.reset
  + Fix and enable gating on H306
  + Remove the redundant code
  + Disallow negative image sizes
* Thu Dec 26 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev64.g091f7e6:
  + Adds guard against upload contention
* Wed Dec 25 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev62.gb36b4d6:
  + Adding missing copy_from policy from policy.json
* Tue Dec 24 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev60.gc692fb9:
  + Make Glance code base H201 compliant
  + Merge duplicate function test_update_add_property()
  + Make Glance code base H102 compliant
  + Rename duplicate test_add_copy_from_upload_image_unauthorized
* Sat Dec 21 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev54.g071ba55:
  + Filter out deleted images from storage usage
  + Refine output of glance service managment
* Fri Dec 20 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev50.g448ef4a:
  + remove hardcode of usage
* Thu Dec 19 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev48.g0d0bbfb:
  + Return 204 when image data does not exist
  + Fixes HTTP 500 when updating image with locations for V2
* Wed Dec 18 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev44.g06848e5:
  + Enable tasks REST API for async worker
  + Forbidden update message diffs images/tasks/member
  + Cleanly fail when location URI is malformed
  + V2: disallow image format update for active status
* Tue Dec 17 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev36.gf54de77:
  + Remove unused exceptions
* Sun Dec 15 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev34.g92fc277:
  + Fix and enable gating on H702
* Sat Dec 14 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev32.gaa67b51:
  + Replace startswith by more precise store matching
  + Fix simple-db image filtering on extra properties
  + assertEquals is deprecated, use assertEqual instead
* Fri Dec 13 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev26.g9edcf16:
  + Pin sphinx to <1.2
* Wed Dec 11 2013 dmueller@suse.com
- fix requires
* Wed Dec 11 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev25.g63ab7f0:
  + Enforce copy_from policy during image-update
  + Remove duplicate method __getitem__ in quota/__init__.py
* Tue Dec 10 2013 dmueller@suse.com
- remove glance-dont-test-qpid.patch, apparently merged
  upstream
* Tue Dec 10 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev21.g1f51bfb:
  + Use assertEqual instead of assertEquals in unit tests
  + DB migration changes to support DB2 as sqlalchemy backend
  + Remove unused package in requirement.txt
  + Add config option to limit image tags
  + Add config option to limit image members
  + Migrate to oslo.messaging
  + Set upload_image policy to control data upload
  + Add documentation for some API parameters
  + Introduce Task Info Table
  + Move is_image_sharable to registry api
  + Unittests added for glance/cmd/cache_manage.py
  + Makes tasks owner not nullable in models.py
  + RBD add() now returns correct size if given zero
  + Remove TestRegistryDB dependency on TestRegistryAPI
  + Refactor StorageQuotaFull test cases in test_quota
  + Added error logging for http store
  + Glance image-list failed when image number exceed DEFAULT_PAGE_SIZE
  + Tests added for glance/cmd/cache_cleaner.py
* Tue Dec  3 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev170.g6628666:
  + Don't use deprecated module commands
  + Enable F40X checking
  + Replace deprecated method assertEquals
* Sun Dec  1 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev164.gbdbc76e:
  + Clean up duplicate code in v2.image_data.py
* Sat Nov 30 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev162.g1408ff7:
  + Fix docstring on detail in glance/api/v1/images.py
* Thu Nov 28 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev161.g2f97e12:
  + Add eclipse project files to .gitignore
  + Verify for duplicate location+metadata instances
* Wed Nov 27 2013 opensuse-packaging@opensuse.org
- Rebased patches:
  + patches/glance-dont-test-qpid.patch (only offset)
  + glance-dont-test-qpid.patch (manually)
* Wed Nov 27 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev157.gccb82b7:
  + Add upload policy for glance v2 api
  + Adding an image status transition diagram for dev doc
  + Remove lxml requirement
  + Documentation for using policies for protected properties
  + Add tests for glance/notifier/notify_kombu
  + Use common db model class from Oslo
  + Adds domain level support for tasks
  + Fixed quotes in _assert_tables() method
* Tue Nov 26 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev141.g8a9cf72:
  + Explicit listing of Glance policies in json file
  + Add config option to limit image properties
  + Cleanup and make HACKING.rst DRYer
  + Log a message when image object not found in swift
* Mon Nov 25 2013 dmueller@suse.com
- switch to python-setuptools
* Mon Nov 25 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev133.gecf2ed2:
  + Fixes content-type checking for image uploading in API v1 and v2
  + Sync openstack.common.local from oslo
  + Log unhandled exceptions
* Sun Nov 24 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev127.g6f503d2:
  + Imported Translations from Transifex
* Sat Nov 23 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev126.ga9e1f7d:
  + Clean up numeric expressions with oslo constants
  + Add tests for glance/image_cache/client.py
* Fri Nov 22 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev122.g0d93999:
  + Sync common db and db.sqlalchemy code from Oslo
  + Fixes image delete and upload contention
* Sun Nov 17 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev119.g3428e6d:
  + Update glance/opensatck/common from oslo Part 3
* Fri Nov 15 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev118.g94aad9e:
  + Sync lockutils from oslo
  + Convert Windows to Unix style line endings
  + Remove redundant dependencies in test-requirements
  + Adds tasks to db api
  + Update my mailmap
  + glance-manage should work like nova-manage
* Thu Nov 14 2013 speilicke@suse.com
- Update to version 2014.1.dev115.g9e439a1:
  + Document default log location in config files
  + Fixes error message encoding issue when using qpid
  + assertEquals is deprecated, use assertEqual
  + Glance v2: Include image/member id in 404 Response
  + Add unit test cases for get func of db member repo
  + Changed header from LLC to Foundation based on trademark policies
  + Remove unused method setup_logging
  + Remove "image_cache_invalid_entry_grace_period" option
  + Remove use of locals() when creating messages
  + sync log from oslo
  + Enable H501: do not use locals() for formatting
  + Add policy style '@'/'!' rules to prop protections
- Rebased patches:
  + glance-dont-test-qpid.patch (only offset)
* Fri Nov  8 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev92.g153e33a:
  + Sync units module from olso
* Thu Nov  7 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev90.ge62c5b0:
  + Start using PyFlakes and Hacking
  + Fix Pep8 1.4.6 warnings
* Mon Nov  4 2013 jsuchome@suse.cz
- updated package requirements (based on latest requirements.txt)
* Sat Nov  2 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev87.g0c1f60d:
  + Use mock in test_policy
* Fri Nov  1 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev86.g650c311:
  + Fixes wrong Qpid protocol configuration
  + Use HTTP storage to test copy file functionality
* Thu Oct 31 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev82.g4e7c8e6:
  + Imported Translations from Transifex
  + Use packaged version of ordereddict
* Wed Oct 30 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev80.ge8fc1ae:
  + checking length of argument list in "glance-cache-image" command
* Tue Oct 29 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev78.gc0e3602:
  + Replace qpid_host with qpid_hostname
* Tue Oct 29 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev76.gf664fb4:
  + Update my mailmap
  + Avoid redefinition of test
  + Addition of third example for Property Protections
* Mon Oct 28 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.a70.g638e9e6:
  + Convert Windows to Unix style line endings
  + Remove redundant dependencies in test-requirements
  + Adds tasks to db api
* Fri Oct 25 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.a64.g8160ae2:
  + Sync iso8601 requirement and fixes test case failures
* Fri Oct 18 2013 speilicke@suse.com
- Update to version 2014.1.a63.g56b225f:
  + optimize queries for image-list
  + Using policies for protected properties
- Package property-protections-policies.conf.sample and
  property-protections-roles.conf.sample
* Thu Oct 17 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.a59.g29c0c00:
  + Refactor glance/tests/unit/v1/test_registry_client.py
  + Use built-in print() instead of print statement
* Thu Oct 17 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.a55.g9117488:
  + Remove unused import
  + Put formatting operation outside localisation call
  + Correct documentation related to protected properties
  + Enable tasks data model and table for async worker
  + Add call to get specific image member
  + V2 RpcApi should register when db pool is enabled
  + Updated from global requirements
* Wed Oct 16 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.a43.gf4a3def:
  + The V2 Api should delete a non existent image
  + Improve test/utils.py
  + Refactor glance/tests/unit/v2/test_registry_client.py
  + Fix typo in config string
  + Removed unsued import, HTTPError in v1/images.py.
  + Code dedup in glance/tests/unit/v1/test_registry_api.py
* Mon Oct 14 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.a31.gb0e09db:
  + Allow tests to run with both provenances of mox
  + Adding 'download_image' policy enforcement to image cache middleware
  + Fix misused assertTrue in unit tests
  + Do not allow the same member to be added twice
  + Glance manage should parse glance-api.conf
  + Remove the unused mapper of image member create
  + Remove start index 0 in range()
  + Glance GET /v2/images fails with 500 due to erroneous policy check
  + Fixes rbd _delete_image snapshot with missing image
  + Update functional tests for swift changes
  + Avoid printing URIs which can contain credentials
  + Use Unix style LF instead of DOS style CRLF
  + Enclose command args in with_venv.sh
  + Remove whitespace from cfg options
* Wed Oct  9 2013 dmueller@suse.com
- run db migrations upon starting the API daemon
* Wed Oct  2 2013 dmueller@suse.com
- update to 2013.2.rc1 release tarball:
  * no changes
* Wed Oct  2 2013 speilicke@suse.com
- Update to version 2013.2.a199.g04cd202:
  + Corrected v2 image sharing documentation.
  + Fixing glance-api hangs in the qpid notifier
  + Imported Translations from Transifex
  + Add rbd store support for zero size image
- Refresh glance-dont-test-qpid.patch
* Tue Oct  1 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a191.gf4f2a82:
  + Fixes typos of v1 meta data in glanceapi.rst
  + Add documentation for property protections
* Sun Sep 29 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a187.g7605ebb:
  + Fixes V2 member-create allows adding an empty tenantId as member
  + Adding checking to prevent conflict image size
* Sat Sep 28 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a183.g567fab9:
  + Add swift_store_ssl_compression param
* Fri Sep 27 2013 dmueller@suse.com
- switch to crudini
* Thu Sep 26 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a181.gf6dc40f:
  + Change response code for successful delete image member to 204.
* Thu Sep 26 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a179.g8c31de4:
  + Require oslo.config 1.2.0 final
  + Cache cleaner wrongly deletes cache for non invalid images
* Wed Sep 25 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a175.g4efd136:
  + Ensure prop protections are read/enforced in order
  + Disallow access/modify members of deleted image
  + Convert location meta data from pickle to string.
* Tue Sep 24 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a169.g4f4b478:
  + Funtional Tests should call glance.db.get_api
* Fri Sep 20 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a168.g4954ea5:
  + Adding encryption support for image multiple locations
* Thu Sep 19 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a166.g26a47e7:
  + Respond with 410 after upload if image was deleted
* Wed Sep 18 2013 dmueller@suse.com
- fix requires
* Sun Sep 15 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a165.g4164949:
  + Convert non-English exception message when a store loading error
* Wed Sep 11 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a163.g272a223:
  + Fix typo in protected property message
  + add missing index for 'owner' column on images table.
* Tue Sep 10 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a160.g08987b1:
  + Implement protected properties for API v1
* Fri Sep  6 2013 speilicke@suse.com
- Update to version 2013.2.a159.g2b2b5f3:
  + Notify error not called on upload errors in V2
  + Update schema descriptions to indicate readonly
  + Rule parser for property protections
  + Property Protection Layer
  + Enable protected properties in gateway
  + Call _post_downgrade_### after downgrade migration is run
  + Add unit test for migration 012
  + Fix localisation string usage
  + Fixes files with wrong bitmode
  + Prefetcher should perform data integrity check
  + Publish recent api changes as v2.2
  + Removes duplicate options registration in registry clients
  + Fix typo in IMAGE_META_HEADERS
  + emit warning while running flake8 without virtual env
  + Remove unused import
- Refresh glance-dont-test-qpid.patch
- Package /etc/glance/property-protections.conf.sample
* Wed Sep  4 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a129.ge4665ad:
  + Scrubber refactoring
  + Clean up data when store receiving image occurs error
  + Show traceback info if a functional test fails
  + Remove unused local vars
  + Introduced DB pooling for non blocking DB calls
* Tue Sep  3 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a120.g0e77554:
  + test failure induced by reading system config file
* Mon Sep  2 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a118.g2cb68ac:
  + Remove unused import of oslo.config
  + Fix Sphinx warning
* Thu Aug 29 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a114.g35fcfdd:
  + Fix up trivial License mismatches
  + Sync models with migrations
  + Remove unused var DEFAULT_MAX_CACHE_SIZE
  + Add a storage quota
* Wed Aug 28 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a106.g67c8316:
  + Implement image query by tag
  + Fix useless assertTrue
* Tue Aug 27 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a102.g6735fbb:
  + Use latest Oslo's version
  + Make size/checksum immutable for active images
  + Allow tests to run without installation
  + Use _pre_upgrade_### instead of _prerun_###
  + Improve the error msg of v2 image_data.py
* Mon Aug 26 2013 dmueller@suse.com
- Update to version 2013.2.a93.gf5cef52:
  + redundant conditions in paginate-query
  + Make sure owner column doesn't get dropped during downgrade
  + Perform database migration snake walk test correctly
  + Remove glance CLI man page.
  + image-delete fires multiple queries to delete its child entries
  + glance-replicator: enable logging exceptions into log file
  + remove flake8 option in run_tests.sh
  + Add v1 API x-image-meta- header whitelist
* Wed Aug 21 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a77.gb0f5f04:
  + Make disk and container formats configurable
* Tue Aug 20 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a75.g38f7de7:
  + Update .mailmap
  + Text formatting changes
  + Adding metadata checking to image location proxy layer
* Mon Aug 19 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a69.g0573985:
  + Add space in etc/glance-cache.conf
* Sat Aug 17 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a68.g9cd75d0:
  + Unit tests for scrubber
* Thu Aug 15 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a66.g63b6438:
  + Fix some logic in get_caching_iter
* Mon Aug 12 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a65.g563c71c:
  + Handle None value properties in glance-replicator
  + Interpolate strings after calling _()
* Sat Aug 10 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a61.g8302c42:
  + Migrate to PBR for setup and version code.
* Thu Aug  8 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a60.g19e32e6:
  + Raise jsonschema requirement
  + Using unicode() convert non-English exception message
  + BaseException.message is deprecated since Python 2.6
  + Fixes Opt types in glance/notifier/notify_kombu.py
* Mon Aug  5 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a54.g463f322:
  + ambiguous column 'checksum' error when querying image-list(v2).
* Mon Aug  5 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a52.g766c842:
  + Add unit test for migration 010
* Fri Aug  2 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a50.gc56fa55:
  + Turn off debug logging in sqlalchemy by default
  + Stub out dependency on subprocess in unit tests
* Fri Aug  2 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a46.g4b12897:
  + Don't rely on prog.Name for paste app
* Tue Jul 30 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a44.gc92aa52:
  + Fix stubs setup and exception message formatting
  + add doc/source/api in gitignore
  + Include pipeline option for using identity headers
* Tue Jul 30 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a38.gd0314c0:
  + Rename requirements files to standard names.
* Tue Jul 30 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a37.g5903555:
  + Adding arguments pre-check for glance-replicator
  + Allow insecure=True to be set in swiftclient
  + Use cross-platform 'ps' for test_multiprocessing
* Mon Jul 29 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a32.g0484ca2:
  + Adds help messages to mongodb_store_db and mongodb_store_uri
* Sat Jul 27 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a30.ge9c9cf1:
  + Remove support for sqlalchemy-migrate < 0.7
* Fri Jul 26 2013 opensuseapi@lsmod.de
- add BuildRequires: python-oslo.sphinx
* Fri Jul 26 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a28.g4527609:
  + Use oslo.sphinx and remove local copy of doc theme
  + Handle client disconnect during image upload
  + Remove references to clean arg from cache-manage
  + Ignore files created by Sphinx build
  + Fix doc formatting issue
  + Fix list formatting in docs
  + improving error handling in chunked upload
  + Fix cache delete-all-queued-images for xattr
  + Glance api to pass identity headers to registry v1
  + Simulate image_locations table in simple/api.py
  + Verify if the RPC result is an instance of dict
* Fri Jul 19 2013 dmueller@suse.com
- move requirements to the right place
* Thu Jul 18 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a6.gddd5e34:
  + Fix 'glance-cache-manage list-cached' for xattr
  + Notify does not occur on all image upload fails
  + File system store can send metadata back with the location.
* Thu Jul 18 2013 berendt@b1-systems.de
- added missing requirement python-cinderclient >= 1.0.4
* Wed Jul 17 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a116.gd13493b:
  + Adding a policy layer for locations APIs
  + index checksum image property
  + removed unused variable 'registry_port'
  + Adding Cinder backend storage driver to Glance
* Tue Jul 16 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a110.gc39cf15:
  + Deleting image that is uploading leaves data
  + Fix 'glance-cache-manage -h' default interpolation
  + Sync gettextutils from oslo
  + DB Driver for the Registry Service
* Sun Jul 14 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a102.g8f01575:
  + Add/remove/replace locations from an image
  + Adds missing error msg for HTTPNotFound exception
* Sat Jul 13 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a98.g996baf8:
  + Adding multiple locations support to image downloading
* Fri Jul 12 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a97.g76e75ce:
  + Sync install_venv_common from oslo
  + Pin kombu and anyjson versions
  + Fixes image-download error of v2
  + On deleting an image, its image_tags are not deleted.
  + Allow storage drivers to add metadata to locations
  + Make db properties functions consistent with the DB API
* Thu Jul 11 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a85.g67ec72d:
  + Add custom RPC(Des|S)erializer to common/rpc.py
  + Make eventlet hub choice configurable.
  + Adding store location proxy to domain
* Tue Jul  9 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a79.g229e482:
  + use tenant:* as swift r/w acl
  + Add location specific information to image locations db
* Tue Jul  9 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a75.g85cbff0:
  + Add image id to the logging message for upload
* Mon Jul  8 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a74.gce75545:
  + Dont raise NotFound in simple db image_tag_get_all
  + Fix stale process after unit tests complete
  + Add Sheepdog store
  + Use python module loading to run glance-manage
* Mon Jul  8 2013 vuntz@suse.com
- Stop shipping wsgi files and SSL certificates for apache setup,
  as glance can handle SSL directly now:
  + Drop openstack-glance-api.wsgi.
  + Remove apache2 BuildRequires, and apache2-utils and openssl
    Requires(post).
  + Do not generate certificates in %%post.
* Fri Jul  5 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a66.g2538660:
  + Refactor unsupported default store testing
* Tue Jul  2 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a65.g9daf387:
  + Updated documentation to include notifications introduced in Grizzly.
* Sat Jun 29 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a63.gfaff611:
  + Add a bit of description
* Fri Jun 28 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a61.gb977362:
  + Port slow, overly assertive v1 functional tests to integration tests
  + Fixes exposing trace during calling image create API
  + Removed unusued variables to clean the code.
* Thu Jun 27 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a56.gb8a13ea:
  + Don't run store tests without a store!
  + Fix for unencrypted uris in scrubber queue files
* Thu Jun 27 2013 speilicke@suse.com
- Drop glance-default-signing_dir.patch: Isn't used any more
- Move secure file attributes to /etc/glance/glance-*.conf instead of
  /etc/glance/glance-*-paste.ini since respective values moved upstream
* Wed Jun 26 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a52.ga880ab4:
  + Do not raise NEW exceptions
  + Import sql_connection option before using it.
* Mon Jun 24 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a48.g52958e4:
  + Do not send traceback to clients by default
* Mon Jun 24 2013 speilicke@suse.com
- Install all files from etc/ into /etc/glance (/etc/schema-image.json
  was missing before) (#bnc826328, bnc#780210)
* Thu Jun 20 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a46.g9dd8a85:
  + Fix incorrect assertion in test_create_pool
* Mon Jun 17 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a45.gbf3d19f:
  + Replace openstack-common with oslo in HACKING.rst
* Fri Jun 14 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a43.g56a94c6:
  + Remove explicit distribute depend.
  + Add a policy layer for membership APIs
  + Use Python 3.x compatible octal literals
* Thu Jun 13 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a37.gca5425e:
  + Add missing Keystone settings to scrubber conf
  + Prevent '500' error when admin uses private marker
  + Remove routes collection mappings
* Wed Jun 12 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a31.gaae7252:
  + Sql query optimization for image detail
* Tue Jun 11 2013 dmueller@suse.com
- add missing dependency to six and pyOpenSSL
* Tue Jun 11 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a29.g6019f15:
  + Pass configure_via_auth down to auth plugin
  + python3: Introduce py33 to tox.ini
* Fri Jun  7 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a25.g2c73455:
  + Prevent E500 when listing with null values
  + Patch changes Fedora 16 to 18 on install page.
* Wed Jun  5 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a21.gc043f30:
  + Move sql_connection option into sqlalchemy package.
  + Remove unused dictionary from test_registry_api.py
* Tue Jun  4 2013 speilicke@suse.com
- Add glance-dont-test-qpid.patch: We don't have packages for it
* Mon Jun  3 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a17.g98dcfb4:
  + updated content_type in the exception where it is missing.
* Fri May 31 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a16.g1797d83:
  + Fix pydevd module import error
  + Don't make functional tests inherit from IsolatedUnitTest
  + Encode headers and params
  + Add qpid-python to test-requires
* Wed May 29 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a147.gfdf81b2:
  + Add documentation on reserving a Glance image
  + Make passing user token to registry configurable
  + Sync oslo imports to the latest version.
  + Import strutils from oslo, and convert to it.
  + Fix undefined variable in cache
* Wed May 29 2013 dmueller@suse.com
- remove setBadness call from rpmlintrc
* Mon May 27 2013 dmueller@suse.com
- add missing requires to test subpackage
* Sun May 26 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a138.ge549be8:
  + Respond with 412 after upload if image was deleted.
  + rbd: return image size when asked
  + rbd: remove extra str() conversions and test with unicode
  + Improve unit tests for glance.api.v1 module
  + RBD store uses common utils for reading file chunks
  + Prevent '500' error when using forbidden marker
* Fri May 24 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a126.g22fdbcb:
  + Add GLANCE_LOCALEDIR env variable
* Thu May 23 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a124.g685382d:
  + Add unittests for image upload functionality in v1
  + Improve unit tests for glance.common package
* Wed May 22 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a120.g8f37488:
  + tests: remove unused methods from test_s3 and test_swift
  + Remove glance-control from the test suite
  + Small change to 'is_public' documentation
  + Remove gettext.install() from glance/__init__.py
* Mon May 20 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a112.gb901d92:
  + Improve unit tests for glance.common.auth module
* Fri May 17 2013 dmueller@suse.com
- adjust d2to1 runtime dependency
* Thu May 16 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a110.g00da175:
  + Redirects requests from /v# to /v#/ with correct Location header
* Wed May 15 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a108.g2b43bc9:
  + Add RBD support with the location option
  + Implement Registry's Client V2
* Fri May 10 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a104.g252ef06:
  + Use flake8/hacking instead of pep8.
* Thu May  9 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a102.ge470732:
  + Add documentation for query parameters
* Wed May  8 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a100.g00cc32c:
  + Fix test_mismatched_X test data deletion check
* Tue May  7 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a99.gf72ed76:
  + Implement registry API v2
* Fri May  3 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a98.g926b6c9:
  + Fix functional test 'test_copy_from_swift'
* Thu May  2 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a96.gcc938e2:
  + Use RBAC policy to determine if context is admin.
* Thu May  2 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a95.g2781f41:
  + Gracefully handle qpid errors
  + Call os.kill for each child instead of the process group
  + Compress response's content according to client's accepted encoding
  + Don't raise HTTPForbidden on a multitenant environment
  + Remove unused configure_db function
  + Expand HACKING with commit message guidelines
  + Convert scripts to entry points
  + Redirects requests from /v# to /v#/
  + Create package for registry's client
* Sat Apr 27 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a79.g3acd2a5:
  + Remove internal store references from migration 015
* Fri Apr 26 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a77.gf9add16:
  + scrubber: dont print URI of image to be deleted
* Thu Apr 25 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a75.gd415611:
  + Functional tests use a clean cached db that is only created once.
* Wed Apr 24 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a74.gd3c5a6c:
  + Call monkey_patch before other modules are loaded
  + Fixes for mis-use of various exceptions
* Tue Apr 23 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a71.g61981f6:
  + Add a policy handler to control copy-from functionality
  + Eliminate the race when selecting a port for tests.
  + Raise 404 while deleting a deleted image
* Mon Apr 22 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a65.gb56491f:
  + Check if creds are present and not None
  + Add tests for image visibility filter in db
  + Reformat openstack-common.conf
  + Standardize on newer except syntax
  + fixes use the fact that empty sequences are false
  + Directly verifying that time and socket are monkey patched
  + Fix domain database initialization
  + Fallback to inferring image_members unique constraint name
  + Add image_size_cap documentation
  + Return 413 when image_size_cap exceeded
  + Pin SQLAlchemy to 0.7.x
  + Add 'set_image_location' policy option
  + remove deprecated assert_unicode sqlalchemy attribute
  + Make is_public an argument rather than a filter.
  + Invalid reference to self in functional test test_scrubber.py
  + Functional tests display the logs of the services they started
  + Remove internal store references from migration 017
  + Small change to exception handling in swift store
  + Adding help text to the options that did not have it.
  + glance-manage should not require glance-registry.conf
  + Add placeholder migrations to allow backports
  + Make "private" functions that shouldn't be exported
  + Imported Translations from Transifex
  + Imported Translations from Transifex
  + Imported Translations from Transifex
  + Sync with oslo-incubator copy of setup.py and version.py
  + Fix test redifinitions
  + Add GridFS store
  + Improve unit tests for glance.api.middleware.cache module
  + Fix the deletion of a pending_delete image.
  + Fix Qpid test cases
  + Add unit tests for glance.api.cached_images module
  + Verify SSL certificates at boot time
  + Fix functional test 'test_scrubber_with_metadata_enc'
* Mon Mar 25 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a117.ga3c0a5f:
  + Handle Swift 404 in scrubber
  + Don't print sql password in debug messages
  + Delete swift segments when image_size_cap exceeded
  + bump version to 2013.2
* Mon Mar 18 2013 speilicke@suse.com
- Drop +git.$TIMESTAMP.$COMMITHASH version suffix
* Sun Mar 17 2013 cloud-devel@suse.de
- Update to version 2013.1.a110.g975c5ac+git.1363479139.975c5ac:
  + Fix calls to image_member_find in tests
  + Retain migration 12 indexes for table image_properties with sqlite.
  + Fix up publicize_image unit test
  + Mark password options secret
  + Fix visibility on db image_member_find
  + Switch to final 1.1.0 oslo.config release
  + Honor metadata_encryption_key in glance domain
  + Publish API version 2.1
  + Insure that migration 6 retains deleted image property index.
  + Log when image_size_cap has been exceeded
  + Fix circular import in glance/db/sqlalchemy
  + Fix check_003 method.
  + Declare index on ImageMember model
  + Fix uniqueness constraint on image_members table.
  + Do not return location in headers
  + Segmented images not deleted cleanly from swift.
  + Document the os options config for swift store
  + Fix scrubber and other utils to use log.setup().
  + Fix rabbit_max_retry
* Fri Mar 15 2013 iartarisi@suse.com
- Change ownership of /var/cache/glance to the openstack-glance user
* Fri Mar 15 2013 iartarisi@suse.com
- Move signing_dir to /var/cache/glance/(api|registry)
* Wed Mar 13 2013 cloud-devel@suse.de
- Update to version 2013.1.a77.ge360117+git.1363133732.e360117:
  + Characterize image_member_find
* Tue Mar 12 2013 dmueller@suse.com
- python-oslo-config -> python-oslo.config
* Mon Mar 11 2013 dmueller@suse.com
- Add sqlalchemy-update.diff:
  * Support SQLAlchemy 0.7.10
* Mon Mar 11 2013 cloud-devel@suse.de
- Update to version 2013.1.a76.gdf7d9c7+git.1362995897.df7d9c7:
  + Refactor leaky abstractions
  + A test for concurrency when glance uses sleep.
  + Generate notification for cached v2 download
  + Update acls in the domain model
  + Switch to oslo.config.
  + Remove unused variable 'image_member_factory'
  + Ensure disk_ and container_format during upload
  + Fix v2 data upload to swift
* Tue Mar  5 2013 cloud-devel@suse.de
- Update to version 2013.1.a62.g3597718+git.1362503747.3597718:
  + Pin jsonschema version below 1.0.0.
  + Fix migration 016 for sqlite.
  + Refactor data migration tests
  + Fix broken JSON schemas in v2 tests
  + Redact location from notifications
  + Removed controversial common image property 'os_libosinfo_shortid'
  + Add migration 021 set_engine_mysql_innodb
  + Add check for image_locations table
  + monkey_patch the time module for eventlet
  + Enable support for MySQL with test migrations.
  + Remove unused imports
  + Fix response code for successful image upload.
  + Parse JSON Schema Draft 10 in v2 Image update
  + Set status to 'active' after image is uploaded
  + Add PostgreSQL support to test migrations.
  + Add pre and check phases to test migration 004
  + Add pre and check phases to test migration 005
  + Update db layer to expose multiple image locations
  + Added better schemas for image members, revised tests.
  + Test date with UTC instead of local timezone.
  + v1 api image-list does not return shared images
  + Cannot change locations on immutable images
  + Add pre and check phases to test migration 006
  + Update documentation to reflect API v2 image sharing
* Mon Feb 25 2013 saschpe@suse.de
- Set 'notifier_strategy' configurable to support ceilometer
* Mon Feb 25 2013 saschpe@suse.de
- Drop sysconfig from init scripts
* Sun Feb 24 2013 cloud-devel@suse.de
- Update to version 2013.1.a21.gaa01e82+git.1361729603.aa01e82:
  + Add migration 18 - create the image_locations table
  + Use install_venv_common.py from oslo.
  + Add an update option to run_tests.sh
  + Create connection for each qpid notification.
  + Use oslo-config-2013.1b3
  + Adding new common image properties
  + Sync latest install_venv_common.py
  + Filter images by status and add visibility shared
  + Extend the domain model to v2 image data
  + Add migration 19 - move image location data
  + Add migration 20 - drop images.location
  + Update oslo-config version.
  + Document db_auto_create in default config files
  + Remove compat cfg wrapper
  + Use more-specific value for X-Object-Manifest header.
  + Fix migration 015 downgrade with sqlite.
  + Remove unnecessary logging from migration 019
  + Update openstack.common
  + Avoid using logging in signal handlers
* Fri Feb 22 2013 saschpe@suse.de
- Require openstack-suse-macros instead of openstack-macros
* Thu Feb 21 2013 iartarisi@suse.com
- Add oslo-config requirement
* Mon Feb 18 2013 saschpe@suse.de
- Init script cleanup:
  + Drop useless shell variables
  + Don't depend on $network facility, we already have $remote_fs
    (comes after $network)
  + Source /etc/sysconfig/openstack-glance (if available), orthogonal
    to the other init scripts we provide. We're not using this feature
    ATM though
  + Use one init script template for all daemons
- Default configuration cleanup:
  + Use openstack-utils to set as much default values in the package
    as possible (instead of patch/sed/...). Some may be overwritting
    later on by, .e.g., crowbar
- More useful lograte configuration:
  + Compress
  + Make sure to keep log files for at least 90 days (i.e. rotate 15
    + weekly = 15 weeks).
  + Add size=1M to avoid getting DoS'ed by wild daemons
  + Use copytruncate instead of create+postrotate+sharedscripts to
    avoid a daemon restart
- Drop glance-webob12b1-putrequest.patch: Not applied currently
* Mon Feb 18 2013 cloud-devel@suse.de
- Update to version 2013.1.a108.gf071f5a+git.1361180194.f071f5a:
  + Rearrange db tests in prep for testr.
  + Update HACKING.rst per recent changes
  + Encrypt scrubber marker files
  + Additional image member information
  + Avoid dangling partial image on size/checksum mismatch
  + Convert some prints to addDetails calls.
  + Image Member Domain Model
  + Adding database layer for image members domain model
  + Fix moker typo in test_notifier
  + Clean dangling image fragments in filesystem store
  + Adding finer notifications.
  + Add _FATAL_EXCEPTION_FORMAT_ERRORS global.
  + Sample config and doc for the show_image_direct_url option.
  + Replace nose plugin with testtools details.
  + Add LazyPluggable utility from nova.
  + Fix version issue during nosetests run
  + Update .coveragerc
  + Add migration.py based on the one in nova.
  + Fix issues with migration 012
  + Updated_at not being passed to db in image create
  + Adding image members in glance v2 api
  + Add status column to image_members
  + Updates OpenStack LLC with OpenStack Foundation
  + Allowing member to set status of image membership
  + Add migration to quote encrypted image location urls
* Mon Feb 11 2013 cloud-devel@suse.de
- Update to version 2013.1.a58.gc9f493e+git.1360595182.c9f493e:
  + Allow description fields to be translated in schema
  + Removed unnecessary code.
  + Quote action strings before passing to registry
  + Add to multi-tenant swift store documentation
  + Mark password config options with secret
* Mon Feb  4 2013 dmueller@suse.com
- Update to version 2013.1.a50.g7feecf1+git.1359978899.7feecf1:
  + Fixes 'not in' operator usage
  + Stop using detailed-errors plugin for nose.
  + Fix kwargs in xattr BadDriverConfiguration exc.
  + Prints list-cached dates in isoformat
  + Fail sensibly if swiftclient absent in test
  + Initialize CONF properly in store func tests
  + Ensure swift_store_admin_tenants ACLs are set
  + Remove Swift location/password from messages.
* Mon Jan 28 2013 dmueller@suse.com
- Update to version 2013.1.a34.g1c01cf1+git.1359364893.1c01cf1:
  + Removed unnecessary code
  + Removed unncessary code
  + Updated image loop to not use an enumerator
  + Log exception details.
* Thu Jan 24 2013 saschpe@suse.de
- Update glance-default-signing_dir.patch to fix the signing-dir
  locations for the moment. This may need further cleanup once we
  decided on how to go forward
* Wed Jan 23 2013 cloud-devel@suse.de
- Update to version 2013.1.a21.g21cf2cf+git.1358959143.21cf2cf:
  + Update version code from oslo
  + Avoid testtools 0.9.25
* Wed Jan 23 2013 saschpe@suse.de
- Clean up %%config(noreplace), only logrotate config and *.conf
  files should be noreplace
* Mon Jan 21 2013 dmueller@suse.com
- Update to version grizzly.2.19.g43f8697+git.1358761745.43f8697:
  + Replace custom tearDown with fixtures and cleanup.
  + Update version code from oslo.
  + Use testtools for unittest base class.
* Mon Jan 14 2013 saschpe@suse.de
- Update to version 2013.1+git.1358168643.2d9b3f1:
  + Set content-length despite webob
  + Update common openstack code from oslo-incubator
  + Modify the v2 image tags to use domain model
  + Fix broken link in docs to controllingservers
  + Adding a means for a glance worker to connect back to a pydevd debugger.
  + Use imported exception for update_store_acls
  + Fix import order nits
  + Verify size in addition to checksum of uploaded image
  + Use one wsgi app, one dbengine worker.
  + Set Content-MD5 after calling webob.Response._app_iter__set.
  + Modify the v2 image controller to use domain model
  + Log error on failure to load paste deploy app.
  + Configure endpoint_type and service_type for swift
  + Refactor multi-tenant swift store.
  + Add registry_client_timeout parameter
  + Use io.BufferedIOBase.read() instead of io.BytesIO.getvalue().
  + Port to argparse based cfg
  + wsgi.Middleware forward-compatibility with webob 1.2b1 or later
  + Allow running testsuite as root user.
  + Allow newer boto library versions
  + Fixed image not getting deleted from cache.
  + Updates keystone middleware classname in docs.
  + v2 API image upload set image status to active
  + Use auth_token middleware from python-keystoneclient.
  + Add domain proxies that stop unauthorized actions
  + Add domain proxies that do policy.enforce checks
  + Use 'notifications' as default notification queue name
  + Unused variables removed
  + Fixed deleted image being downloadable by admin.
  + Rewrite S3 functional tests
  + Add store test coverage for the get_size method
  + Implement get_size filesystem store method
  + Add an image repo proxy that handles notifications
  + Fixed Typo
  + Return size as int from store get call
  + Wrap log messages with _()
  + Add pep8 ignore options to run_tests.sh
  + Fix typo uudiutils -> uuidutils
  + Make cooperative reader always support read()
  + Add an image proxy to handle stored image data
  + Allow for not running pep8.
  + Refactor where store drivers are initialized
  + Audit error logging
  + Stop logging all registry client exceptions
  + Remove unused imports
  + Add note about urlencoding the sql_connection config opt
  + Add an image repo to encapsulate db api access
  + Add an image domain model and related helpers.
  + Fix simple db image_get to look like sqlalchemy
  + Return 403 on images you can see but can't modify
  + Fixes is_image_visible to not use deleted key
  + Ensure strings passed to librbd are not unicode
  + Use generate_uuid from openstack common.
  + Update uuidutils from openstack common
  + Code cleanup: remove ImageAddResult class.
  + Lowering certain log lines from error to info
  + Prevent infinite respawn of child processes
  + Make run_tests.sh run pep8 checks on bin.
  + Make tox.ini run pep8 checks on bin.
  + Pep8 fixes to bin/glance* scripts.
  + Ensure authorization before deleting from store
  + Port uuidutils to Glance
  + Delete from store after registry delete.
  + Unit test remaining glance-replicator methods.
  + Use openstack common timeutils in simple db api
  + Unit test replication_dump.
  + pin sqlalchemy to the 0.7 series
  + DRY up image fetch code in v2 API
  + Return 403 when admin deletes a deleted image
  + Pull in a versioning fix from openstack-common.
  + Fixes deletion of invalid image member
  + Return HTTP 404 for deleted images in v2
  + Update common to 18 October 2012.
  + implements selecting version in db sync
  + add command "status" to "glance-control"
  + Disallow admin updating deleted images in v2 api
  + Clean up is_public filtering in image_get_all
  + SSL functional tests always omitted
  + Fix scrubber not scrubbing with swift backend
  + Add OpenStack trove classifier for PyPI
  + Disallow updating deleted images.
  + Unit test replication_size.
  + Add noseopts and replace noseargs where needed to run_test.sh
  + Setup the pep8 config to check bin/glance-control
  + Change useexisting to extend_existing to fix deprecation warnings.
  + Fix fragile respawn storm test
  + Fix glance filesystem store race condition
  + Add support for multiple db test classes
  + Don't parse commandline in filesystem tests
  + Improve test coverage for replicator's REST client.
  + Correct conversion of properties in headers
  + Add test for v2 image visibility
  + change the default sql connection timeout to 60s
  + Add test for v1 image visibility
  + FakeAuth not always admin
  + Add GLANCE_TEST_TMP_DIR environment var for tests.
  + Call setup_s3 before checking for disabled state.
  + Add insecure option to registry https client
  + Clean up pep8 E128 violations
  + Rename non-public method in sqlalchemy db driver
  + Add image_member_update to simple db api
  + Multiprocess respawn functional test fix
  + Remove unnecessary set_acl calls
  + Clean up pep8 E127 violations
  + Remove notifications on error
  + Change type of rabbit_durable_queues to boolean.
  + Pass empty args to test config parser.
  + Document api deployment configuration
  + Clean up pep8 E125 violations
  + Clean up pep8 E124 violations
  + Ensure workers set to 0 for all functional tests
  + image_member_* db functions return dicts
  + Alter image_member_[update|delete] to use member id
  + Add test for db api method image_member_create
  + Add test for image_tag_set_all
  + Add rabbit_durable_queues config option.
  + Remove extraneous db method image_property_update
  + Update docs with modified workers default value.
  + Replace README with links to better docs
  + Remove unused animation module
  + Drop Glance Client
  + Enable multi-processing by default.
  + Ensure glance-api application is "greened"
  + Clean up pep8 E122, E123 violations
  + Clean up pep8 E121 violations
  + Fix scrubber start & not scrubbing when not daemon
  + Clean up pep8 E502, E711 violations
  + Expand cache middleware unit tests
  + Change qpid_heartbeat default.
  + Don't WARN if trying to add a scheme which exists.
  + Add unit tests for size_checked_iter
  + Add functional tests for the HTTP store
  + Generalize remote image functional test
  + Add filesystem store driver to new func testing
  + Add region configuration for swift
  + Update openstack-common log and setup code
  + Update v2.0 API version to CURRENT
  + Set new version to open Grizzly development
  + Separate glance cache client from main client
  + Rewrite Swift store functional tests
- Dropped the following patches (merged upstream):
  + glance-lp1083155.patch
  + glance-run-testsuite-as-root.patch
  + glance-test_bin_glance-fail-on-slow-machines.patch
  + glance-webob-1_2b1-compat.patch
  + glance-webob-requestbodyfileget.patch
* Thu Jan 10 2013 saschpe@suse.de
- Add logrotate configuration
* Thu Jan 10 2013 saschpe@suse.de
- Add glance-default-signing_dir.patch: Currently, if not set, the
  default in keystone/middleware/auth_token.py is $HOME/signing_dir
  (See https://bugs.launchpad.net/keystone/+bug/1031022) which may
  fail depending on the user glance / glanceclient is run and
  the home directory set.
* Tue Jan  8 2013 saschpe@suse.de
- Add glance-test_bin_glance-fail-on-slow-machines.patch: Test randomly
  fails because on slow machines, the updated image is still in
  'State: saving'.
* Wed Dec 19 2012 saschpe@suse.de
- Move to obs-service-git_tarballs
- Update to version 2012.2.3+git.1355916805.35260a7:
  + Bump next version to 2012.2.3
* Thu Dec 13 2012 saschpe@suse.de
- Add glance-webob12b1-putrequest.patch: Disable
  test_add_image_with_image_data_as_file_with_sendfile with WebOb >
  1.2b1. Only the testsuite fix has an issue, but there is no upstream
  solution yet (https://review.openstack.org/#/c/18036/)
* Wed Dec 12 2012 saschpe@suse.de
- Delete test_interrupt_avoids_respawn_storm, it has a known race
  and is failing randomly
* Wed Dec 12 2012 saschpe@suse.de
- Add glance-webob-requestbodyfileget.patch: Newer WebOb returns
  different objects, i.e. io.Bytes vs. io.BufferedReader
* Wed Dec 12 2012 saschpe@suse.de
- Add glance-lp1083155.patch: Using response.app_iter = ... resets
  Content-MD5
* Mon Dec 10 2012 saschpe@suse.de
- Add glance-run-testsuite-as-root.patch: Some tests make no sense
  when running as root
- Add glance-webob-1_2b1-compat.patch: Forward compatibility with
  WebOb-1.2b1 or later
* Mon Dec 10 2012 saschpe@suse.de
- Update to version 2012.2.1+git.1354224497.199783c:
  + Bump next version to 2012.2.2
  + Ensure strings passed to librbd are not unicode
  + Make cooperative reader always support read()
  + Return 403 when admin deletes a deleted image
  + Ensure authorization before deleting from store
  + Delete from store after registry delete.
  + FakeAuth not always admin
  + Pull in a versioning fix from openstack-common.
  + Return HTTP 404 for deleted images in v2
  + Disallow updating deleted images.
  + pin sqlalchemy to the 0.7.x series
  + Add noseopts and replace noseargs where needed to run_test.sh
  + Pass empty args to test config parser.
  + Set defaultbranch in .gitreview to stable/folsom
* Wed Dec  5 2012 saschpe@suse.de
- Use @PARENT_TAG@ in _service file to automate versioning
* Thu Nov 22 2012 saschpe@suse.de
- Split out doc package into seperate spec file
- Drop "glance" binary, we have glanceclient
- Fix smaller rpmlint warnings
* Tue Nov 20 2012 saschpe@suse.de
- Add more requirements to the test package:
  + python-glanceclient
  + python-openstack.nose_plugin
* Thu Nov 15 2012 saschpe@suse.de
- Use openstack-macros
* Fri Nov  9 2012 saschpe@suse.de
- Add more test requirements for which we have packages now:
  + Requires: python-nose-exclude
  + Requires: python-nosehtmloutput
  + Requires: python-pysendfile
* Thu Nov  8 2012 saschpe@suse.de
- Drop from_vcs build flag
* Tue Oct 30 2012 saschpe@suse.de
- Drop temporary fixes for file permissions and attributes in %%post
  section. They were necessary only to migrate from pre-1.0 packages.
* Tue Oct  9 2012 vuntz@suse.com
- Update to version 2012.2 (Folsom):
  + See https://github.com/openstack/glance/commits/folsom-3
- Drop the following upstreamed patches:
  + glance-insecure-cmdline-flag-for-auth.patch
  + glance-utf8-headers.patch
- Buildrequire python-base instead of python-devel:
  + Sufficient for Python-only modules (containing no C/C++ code)
- Move bash-completion file to python-glanceclient
- Move runtime Python module requirements from the base package to
  "python-glance"
- Build and install manpages
* Wed Sep 26 2012 bwiedemann@suse.com
- make init script wait for postgresql (bnc#781798)
* Wed Sep 12 2012 vuntz@suse.com
- Do not use a sed to modify /usr/bin/gensslcert in %%post: this
  file belongs to another package, and we actually don't do any
  change with the sed... Fix bnc#779747.
* Thu Aug 23 2012 vuntz@suse.com
- Add glance-utf8-headers.patch: make sure to encode to UTF-8 the
  data we put in HTTP headers. By default, they're unicode and this
  breaks if using mod_wsgi (like in our SSL setup). Fix bnc#776699.
* Tue Aug 14 2012 bwiedemann@suse.com
- rename /usr/bin/glance => glance.essex
  to no more conflict with python-glanceclient
* Fri Aug 10 2012 jenkins@suse.de
- Update to latest git (120fcf4):
  + Final versioning for 2012.1.2
  + Bump version to 2012.1.3
* Wed Aug  8 2012 jenkins@suse.de
- Update to latest git (e91ea80):
  + Make image.upload notification send up2date metadata
  + Include chunk_name in swift debug message
  + Remove microseconds before time format conversion.
* Tue Aug  7 2012 jenkins@suse.de
- Update to latest git (183ea45):
  + Support zero-size image creation via the v1 API
  + Stop revealing sensitive store info
  + fix the qpid_heartbeat option so that it's effective
  + Allow admins to share images regardless of owner.
  + Fix swift dependency at 1.4.8.
* Mon Jul 30 2012 saschpe@suse.de
- Provide glance-api WSGI skeleton
* Fri Jul 27 2012 saschpe@suse.de
- Remove doc/source/_templates/.placeholder
- Provide self-signed SSL certificates to be used for non-production setups
  (like openstack-quickstart)
* Wed Jul 18 2012 saschpe@suse.de
- Add glance-insecure-cmdline-flag-for-auth.patch to fix authentication
  against keystone with self-signed SSL certs
* Tue Jul  3 2012 saschpe@suse.de
- Conflict on python-glanceclient, it also ships /usr/bin/glance
* Wed Jun 27 2012 saschpe@suse.de
- Change versioning scheme to $release+git.$AUTHORDATE.$COMMITREV
- Simplify from_vcs macros
* Tue Jun 26 2012 saschpe@suse.de
- Consistent package summaries
- Use upstream description
- Macro cleanup:
  + Package is noarch except for SLE-11
  + No need to redefine %%_initddir, SLE-11 works correctly
* Tue Jun 12 2012 saschpe@suse.de
- Use 'openstack-glance' system user instead of 'glance'
* Wed Jun  6 2012 saschpe@suse.de
- Add Should-Stop: lines to init scripts (LBS compliance)
* Wed Jun  6 2012 saschpe@suse.de
- Add %%restart_on_update to %%post section for api and registry
  (daemons should be restarted after package update)
- Fix some rpmlint warnings
- Added rpmlintrc for non-issues
* Thu May 24 2012 jfehlig@suse.com
- Add 'Requires: python >= 2.6.8' to openstack-glance and
  python-glance subpackage
* Tue May 22 2012 bwiedemann@suse.com
- make *-paste.ini private
  to not show the admin_token to everyone (bnc#750137)
* Fri Apr 20 2012 bwiedemann@suse.com
- add bash completion for glance
* Thu Apr 19 2012 bwiedemann@suse.com
- drop upstreamed patch
- add patch for https://bugs.launchpad.net/glance/+bug/978907
* Tue Feb 14 2012 bwiedemann@suse.com
- fix init scripts - startproc would not start/stop the second
  glance-{api|registri} because it already saw a glance-control process.
- run as glance user instead of root
* Mon Feb  6 2012 rhafer@suse.de
- Updated to latest git snapshot
* Mon Feb  6 2012 rhafer@suse.de
- Split the init script up into separate ones for -registry and
  - api.
- glance-control needs to be called with --config-file to have
  the services started correctly
* Fri Feb  3 2012 cstender@suse.com
- move *.ini files to /etc/glance/
* Thu Feb  2 2012 rhafer@suse.de
- glance requires python-crypto
* Thu Jan 19 2012 mvidner@suse.cz
- updated to today's git snapshot, adjusted the file list
* Mon Jan 16 2012 prusnak@opensuse.org
- fix initscript scriptlets
* Tue Jan 10 2012 cfarrell@suse.com
- license update: Apache-2.0 and GPL-3.0+
  Use SPDX format. See rfc.sh (GPL-3.0+)
* Tue Dec 13 2011 vuntz@opensuse.org
- Merge changes to enable build from git:
  + The work was done by Christopher Hofmann <cwh@suse.com>.
  + Add from_vcs and no_from_vcs bconds, that can be used in
    addition to the BUILD_FROM_VCS macro to decide what to build.
  + Add some warning to summary of packages is building from VCS.
  + Do not apply patches for the git package.
  + Package files that are new in git.
* Mon Dec  5 2011 prusnak@opensuse.org
- spec cleanup
- added preun/postun sections for initscript handling
* Fri Sep 23 2011 bwiedemann@suse.com
- update to 2011.3 (Diablo)
* Wed Jun  1 2011 berendt@b1-systems.de
- update to bzr rev 139
- fixed version
- fixed URL
* Thu Apr 21 2011 berendt@b1-systems.de
- update to bzr rev 123
  - modified documentation to show more first-time user friendly examples on using glance.
  - Require user confirmation for "bin/glance clear" and "bin/glance delete <id>"
  - Allow for override with -f/--force command-line option
  - Adds a test case for updating an image's Name attribute. glance update was not regarding 'name' as a top-level modifiable attribute...
  - Mark image properties as deleted when deleting images.
  - Added a unit test to verify public images and their properties get deleted when running a 'glance clear' command.
  - Add log_file to example glance.conf
  - Make sure we use get_option() when dealing with boolean values read from configuration files...otherwise "False" is True :(
* Tue Apr 19 2011 berendt@b1-systems.de
- update to bzr rev 116
  - start of diablo release
  - Fake merge with ancient trunk. This is only so that people who "accidentally" have been following lp:~hudson-openstack/glance/trunk will not have problems updating to this.
* Fri Apr 15 2011 berendt@b1-systems.de
- update to bzr rev 114
  - Final versioning for Cactus
- updated version to 2011.2
* Thu Apr 14 2011 berendt@b1-systems.de
- update to bzr rev 113
* Tue Apr 12 2011 berendt@b1-systems.de
- update to bzr rev 108
* Mon Apr  4 2011 berendt@b1-systems.de
- update to bzr rev 100
- Updates to the Registry API such that only external requests to
- update image properties purge existing properties. The update_image
- call now contains an extra flag to purge_props which is set to
- True for external requests but False internally.
- This resolves with revision 99 where Glance API incidentally deleted image metadata when uploading new images.
- Update the glance registry so that it marks properties as deleted if they are no longer exist when images are updated.
- Simple one.. just add back the Changelog I removed by accident in r94. Fixes bug #742353
- Adds checksumming to Glance.
- The ETag header is now properly set to the image's checksum now for all GET /images/<ID>, HEAD /images/<ID>, POST /images and PUT /images/<ID> operations.
- Adds unit tests verifying the checksumming behaviour in the API, and in the Swift and Filesystem backend stores.
- Includes migration script.
-   NOTE: This does not include the DB migration script. Separate bug will be filed for that.
- Add migration testing and migration for disk_format/container_format
- Start eventlet WSGI server with a logger to avoid stdout output.
- Adds robust functional testing to Glance.
- Removed glance-combined. Fixed README
- Change #!/usr/bin/python to #!/usr/bin/env python.
- Removes glance-combined and fixes TypeError from bad function calls in glance-manage.
- Support account:user:key in Swift URIs. Adds unit tests for various calls to parse_swift_tokens()
- Adds documentation on configuring logging and a unit test for checking simple log output
- A quick patch to allow running the test suite on an alternate db backend.
* Thu Mar 17 2011 berendt@b1-systems.de
- added new configuration files
- replaced hardcoded paths in spec file with variables
* Fri Mar 11 2011 berendt@b1-systems.de
- renamed package python-glance to openstack-glance
* Thu Mar 10 2011 berendt@b1-systems.de
- update to bzr rev 86
  - Fixes client update_image to work like create_image.
  - Adds disk_format and container_format to Image, and
    removes the type column.
  - Adds ability for Swift to be used as a full-fledged backend.
  - Adds POST/PUT capabilities to the SwiftBackend
  - Fixes passing of None values in metadata by turning them into strings
  - fixes the passing of the deleted column by converting it to and from a bool
  - Add Glance CLI tool
* Thu Mar  3 2011 berendt@b1-systems.de
- update to bzr rev 79
  - Makes --kernel and --ramdisk required arguments for glance-upload
    since Nova currently requires them
  - Add sys.path mangling to glance-upload
  - Reverts Image `type` back to the old behavior of being nullable
  - Work around Eventlet exception clearing by memorizing exception
    context and re-raising using 3-arg form
* Wed Feb 23 2011 seife+obs@b1-systems.com
- update to bzr rev 74:
  - add vhd as recognized image type
* Wed Feb 16 2011 seife+obs@b1-systems.com
- start tracking development releases
- update to bzr rev 73
  * lots of fixes, see changelog
- glance changed the versioning scheme similar to nova
* Mon Feb 14 2011 seife+obs@b1-systems.com
- fix init script configuration parsing
* Fri Feb 11 2011 seife+obs@b1-systems.com
- add requires for python-eventlet,-webob,-sqlalchemy,-mysql
* Wed Feb  9 2011 seife+obs@b1-systems.com
- add init script to start / stop the glance services
* Thu Feb  3 2011 seife+obs@b1-systems.com
- official bexar release
  * bump version to 0.1.7
* Tue Feb  1 2011 berendt@b1-systems.de
- bumped to version 0.1.6 (bexar-rc, released on 2011-01-28)
- fixed required packages:
  + python-gflags
  + python-daemon
  + python-routes
  + python-argparse
* Wed Jan 26 2011 seife+obs@b1-systems.com
- initial package of python-glance
